from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class QUDT_UNIT(DefinedNamespace):
    # Generated with namespacelib version 0.1.0
    _fail = True
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    R = URIRef("http://qudt.org/vocab/unit/R")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    P = URIRef("http://qudt.org/vocab/unit/P")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    V = URIRef("http://qudt.org/vocab/unit/V")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    L = URIRef("http://qudt.org/vocab/unit/L")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    N = URIRef("http://qudt.org/vocab/unit/N")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    U = URIRef("http://qudt.org/vocab/unit/U")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    K = URIRef("http://qudt.org/vocab/unit/K")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    V = URIRef("http://qudt.org/vocab/unit/V")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    M = URIRef("http://qudt.org/vocab/unit/M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    A = URIRef("http://qudt.org/vocab/unit/A")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    R = URIRef("http://qudt.org/vocab/unit/R")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    L = URIRef("http://qudt.org/vocab/unit/L")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    A = URIRef("http://qudt.org/vocab/unit/A")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    V = URIRef("http://qudt.org/vocab/unit/V")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    H = URIRef("http://qudt.org/vocab/unit/H")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    P = URIRef("http://qudt.org/vocab/unit/P")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    B = URIRef("http://qudt.org/vocab/unit/B")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    N = URIRef("http://qudt.org/vocab/unit/N")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    A = URIRef("http://qudt.org/vocab/unit/A")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    G = URIRef("http://qudt.org/vocab/unit/G")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    R = URIRef("http://qudt.org/vocab/unit/R")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    V = URIRef("http://qudt.org/vocab/unit/V")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    H = URIRef("http://qudt.org/vocab/unit/H")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    G = URIRef("http://qudt.org/vocab/unit/G")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    H = URIRef("http://qudt.org/vocab/unit/H")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    B = URIRef("http://qudt.org/vocab/unit/B")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    F = URIRef("http://qudt.org/vocab/unit/F")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    B = URIRef("http://qudt.org/vocab/unit/B")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    M = URIRef("http://qudt.org/vocab/unit/M")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    S = URIRef("http://qudt.org/vocab/unit/S")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    T = URIRef("http://qudt.org/vocab/unit/T")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    R = URIRef("http://qudt.org/vocab/unit/R")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    N = URIRef("http://qudt.org/vocab/unit/N")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    N = URIRef("http://qudt.org/vocab/unit/N")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    E = URIRef("http://qudt.org/vocab/unit/E")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    B = URIRef("http://qudt.org/vocab/unit/B")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    T = URIRef("http://qudt.org/vocab/unit/T")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    C = URIRef("http://qudt.org/vocab/unit/C")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    F = URIRef("http://qudt.org/vocab/unit/F")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    B = URIRef("http://qudt.org/vocab/unit/B")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    M = URIRef("http://qudt.org/vocab/unit/M")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    C = URIRef("http://qudt.org/vocab/unit/C")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    K = URIRef("http://qudt.org/vocab/unit/K")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    P = URIRef("http://qudt.org/vocab/unit/P")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    U = URIRef("http://qudt.org/vocab/unit/U")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    G = URIRef("http://qudt.org/vocab/unit/G")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    unit = URIRef("http://qudt.org/vocab/unit")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    S = URIRef("http://qudt.org/vocab/unit/S")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    F = URIRef("http://qudt.org/vocab/unit/F")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    L = URIRef("http://qudt.org/vocab/unit/L")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    U = URIRef("http://qudt.org/vocab/unit/U")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    C = URIRef("http://qudt.org/vocab/unit/C")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    S = URIRef("http://qudt.org/vocab/unit/S")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    R = URIRef("http://qudt.org/vocab/unit/R")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    W = URIRef("http://qudt.org/vocab/unit/W")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    P = URIRef("http://qudt.org/vocab/unit/P")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    S = URIRef("http://qudt.org/vocab/unit/S")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    unit = URIRef("http://qudt.org/vocab/unit")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    T = URIRef("http://qudt.org/vocab/unit/T")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    U = URIRef("http://qudt.org/vocab/unit/U")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    N = URIRef("http://qudt.org/vocab/unit/N")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    V = URIRef("http://qudt.org/vocab/unit/V")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    P = URIRef("http://qudt.org/vocab/unit/P")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    U = URIRef("http://qudt.org/vocab/unit/U")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    K = URIRef("http://qudt.org/vocab/unit/K")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    K = URIRef("http://qudt.org/vocab/unit/K")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    B = URIRef("http://qudt.org/vocab/unit/B")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    K = URIRef("http://qudt.org/vocab/unit/K")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    S = URIRef("http://qudt.org/vocab/unit/S")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    B = URIRef("http://qudt.org/vocab/unit/B")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    C = URIRef("http://qudt.org/vocab/unit/C")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    B = URIRef("http://qudt.org/vocab/unit/B")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    unit = URIRef("http://qudt.org/vocab/unit")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    A = URIRef("http://qudt.org/vocab/unit/A")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    W = URIRef("http://qudt.org/vocab/unit/W")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    K = URIRef("http://qudt.org/vocab/unit/K")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    H = URIRef("http://qudt.org/vocab/unit/H")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    A = URIRef("http://qudt.org/vocab/unit/A")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    K = URIRef("http://qudt.org/vocab/unit/K")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    R = URIRef("http://qudt.org/vocab/unit/R")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    A = URIRef("http://qudt.org/vocab/unit/A")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    A = URIRef("http://qudt.org/vocab/unit/A")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    unit = URIRef("http://qudt.org/vocab/unit")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    L = URIRef("http://qudt.org/vocab/unit/L")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    unit = URIRef("http://qudt.org/vocab/unit")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    G = URIRef("http://qudt.org/vocab/unit/G")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    G = URIRef("http://qudt.org/vocab/unit/G")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    S = URIRef("http://qudt.org/vocab/unit/S")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    C = URIRef("http://qudt.org/vocab/unit/C")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    T = URIRef("http://qudt.org/vocab/unit/T")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    V = URIRef("http://qudt.org/vocab/unit/V")
    S = URIRef("http://qudt.org/vocab/unit/S")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    V = URIRef("http://qudt.org/vocab/unit/V")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    U = URIRef("http://qudt.org/vocab/unit/U")
    L = URIRef("http://qudt.org/vocab/unit/L")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    U = URIRef("http://qudt.org/vocab/unit/U")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    K = URIRef("http://qudt.org/vocab/unit/K")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    L = URIRef("http://qudt.org/vocab/unit/L")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    H = URIRef("http://qudt.org/vocab/unit/H")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    E = URIRef("http://qudt.org/vocab/unit/E")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    N = URIRef("http://qudt.org/vocab/unit/N")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    P = URIRef("http://qudt.org/vocab/unit/P")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    U = URIRef("http://qudt.org/vocab/unit/U")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    V = URIRef("http://qudt.org/vocab/unit/V")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    N = URIRef("http://qudt.org/vocab/unit/N")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    K = URIRef("http://qudt.org/vocab/unit/K")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    R = URIRef("http://qudt.org/vocab/unit/R")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    U = URIRef("http://qudt.org/vocab/unit/U")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    A = URIRef("http://qudt.org/vocab/unit/A")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    V = URIRef("http://qudt.org/vocab/unit/V")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    E = URIRef("http://qudt.org/vocab/unit/E")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    J = URIRef("http://qudt.org/vocab/unit/J")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    R = URIRef("http://qudt.org/vocab/unit/R")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    W = URIRef("http://qudt.org/vocab/unit/W")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    H = URIRef("http://qudt.org/vocab/unit/H")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    V = URIRef("http://qudt.org/vocab/unit/V")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    P = URIRef("http://qudt.org/vocab/unit/P")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    K = URIRef("http://qudt.org/vocab/unit/K")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    A = URIRef("http://qudt.org/vocab/unit/A")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    S = URIRef("http://qudt.org/vocab/unit/S")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    F = URIRef("http://qudt.org/vocab/unit/F")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    V = URIRef("http://qudt.org/vocab/unit/V")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    R = URIRef("http://qudt.org/vocab/unit/R")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    E = URIRef("http://qudt.org/vocab/unit/E")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    H = URIRef("http://qudt.org/vocab/unit/H")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    J = URIRef("http://qudt.org/vocab/unit/J")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    A = URIRef("http://qudt.org/vocab/unit/A")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    L = URIRef("http://qudt.org/vocab/unit/L")
    H = URIRef("http://qudt.org/vocab/unit/H")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    unit = URIRef("http://qudt.org/vocab/unit")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    M = URIRef("http://qudt.org/vocab/unit/M")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    N = URIRef("http://qudt.org/vocab/unit/N")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    N = URIRef("http://qudt.org/vocab/unit/N")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    H = URIRef("http://qudt.org/vocab/unit/H")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    B = URIRef("http://qudt.org/vocab/unit/B")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    M = URIRef("http://qudt.org/vocab/unit/M")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    C = URIRef("http://qudt.org/vocab/unit/C")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    C = URIRef("http://qudt.org/vocab/unit/C")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    U = URIRef("http://qudt.org/vocab/unit/U")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    B = URIRef("http://qudt.org/vocab/unit/B")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    R = URIRef("http://qudt.org/vocab/unit/R")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    P = URIRef("http://qudt.org/vocab/unit/P")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    W = URIRef("http://qudt.org/vocab/unit/W")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    J = URIRef("http://qudt.org/vocab/unit/J")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    C = URIRef("http://qudt.org/vocab/unit/C")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    S = URIRef("http://qudt.org/vocab/unit/S")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    C = URIRef("http://qudt.org/vocab/unit/C")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    S = URIRef("http://qudt.org/vocab/unit/S")
    A = URIRef("http://qudt.org/vocab/unit/A")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    W = URIRef("http://qudt.org/vocab/unit/W")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    F = URIRef("http://qudt.org/vocab/unit/F")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    W = URIRef("http://qudt.org/vocab/unit/W")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    S = URIRef("http://qudt.org/vocab/unit/S")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    W = URIRef("http://qudt.org/vocab/unit/W")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    J = URIRef("http://qudt.org/vocab/unit/J")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    K = URIRef("http://qudt.org/vocab/unit/K")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    unit = URIRef("http://qudt.org/vocab/unit")
    C = URIRef("http://qudt.org/vocab/unit/C")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    V = URIRef("http://qudt.org/vocab/unit/V")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    C = URIRef("http://qudt.org/vocab/unit/C")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    H = URIRef("http://qudt.org/vocab/unit/H")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    unit = URIRef("http://qudt.org/vocab/unit")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    M = URIRef("http://qudt.org/vocab/unit/M")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    F = URIRef("http://qudt.org/vocab/unit/F")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    H = URIRef("http://qudt.org/vocab/unit/H")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    A = URIRef("http://qudt.org/vocab/unit/A")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    U = URIRef("http://qudt.org/vocab/unit/U")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    R = URIRef("http://qudt.org/vocab/unit/R")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    S = URIRef("http://qudt.org/vocab/unit/S")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    C = URIRef("http://qudt.org/vocab/unit/C")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    B = URIRef("http://qudt.org/vocab/unit/B")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    S = URIRef("http://qudt.org/vocab/unit/S")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    E = URIRef("http://qudt.org/vocab/unit/E")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    T = URIRef("http://qudt.org/vocab/unit/T")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    unit = URIRef("http://qudt.org/vocab/unit")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    T = URIRef("http://qudt.org/vocab/unit/T")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    L = URIRef("http://qudt.org/vocab/unit/L")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    W = URIRef("http://qudt.org/vocab/unit/W")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    B = URIRef("http://qudt.org/vocab/unit/B")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    S = URIRef("http://qudt.org/vocab/unit/S")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    B = URIRef("http://qudt.org/vocab/unit/B")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    C = URIRef("http://qudt.org/vocab/unit/C")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    W = URIRef("http://qudt.org/vocab/unit/W")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    S = URIRef("http://qudt.org/vocab/unit/S")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    R = URIRef("http://qudt.org/vocab/unit/R")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    W = URIRef("http://qudt.org/vocab/unit/W")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    E = URIRef("http://qudt.org/vocab/unit/E")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    J = URIRef("http://qudt.org/vocab/unit/J")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    W = URIRef("http://qudt.org/vocab/unit/W")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    PERCENT_PER_DektoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DektoKiloCount")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    F = URIRef("http://qudt.org/vocab/unit/F")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    W = URIRef("http://qudt.org/vocab/unit/W")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    N = URIRef("http://qudt.org/vocab/unit/N")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    W = URIRef("http://qudt.org/vocab/unit/W")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    S = URIRef("http://qudt.org/vocab/unit/S")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    H = URIRef("http://qudt.org/vocab/unit/H")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    T = URIRef("http://qudt.org/vocab/unit/T")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    J = URIRef("http://qudt.org/vocab/unit/J")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    F = URIRef("http://qudt.org/vocab/unit/F")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    S = URIRef("http://qudt.org/vocab/unit/S")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    S = URIRef("http://qudt.org/vocab/unit/S")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    M = URIRef("http://qudt.org/vocab/unit/M")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    L = URIRef("http://qudt.org/vocab/unit/L")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    A = URIRef("http://qudt.org/vocab/unit/A")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    U = URIRef("http://qudt.org/vocab/unit/U")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    L = URIRef("http://qudt.org/vocab/unit/L")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    V = URIRef("http://qudt.org/vocab/unit/V")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    T = URIRef("http://qudt.org/vocab/unit/T")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    K = URIRef("http://qudt.org/vocab/unit/K")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    A = URIRef("http://qudt.org/vocab/unit/A")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    N = URIRef("http://qudt.org/vocab/unit/N")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    N = URIRef("http://qudt.org/vocab/unit/N")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    A = URIRef("http://qudt.org/vocab/unit/A")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    W = URIRef("http://qudt.org/vocab/unit/W")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    K = URIRef("http://qudt.org/vocab/unit/K")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    M = URIRef("http://qudt.org/vocab/unit/M")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    W = URIRef("http://qudt.org/vocab/unit/W")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    A = URIRef("http://qudt.org/vocab/unit/A")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    W = URIRef("http://qudt.org/vocab/unit/W")
    W = URIRef("http://qudt.org/vocab/unit/W")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    G = URIRef("http://qudt.org/vocab/unit/G")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    L = URIRef("http://qudt.org/vocab/unit/L")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    R = URIRef("http://qudt.org/vocab/unit/R")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    K = URIRef("http://qudt.org/vocab/unit/K")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    J = URIRef("http://qudt.org/vocab/unit/J")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    G = URIRef("http://qudt.org/vocab/unit/G")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    S = URIRef("http://qudt.org/vocab/unit/S")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    F = URIRef("http://qudt.org/vocab/unit/F")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    T = URIRef("http://qudt.org/vocab/unit/T")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    W = URIRef("http://qudt.org/vocab/unit/W")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    E = URIRef("http://qudt.org/vocab/unit/E")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    M = URIRef("http://qudt.org/vocab/unit/M")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    U = URIRef("http://qudt.org/vocab/unit/U")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    C = URIRef("http://qudt.org/vocab/unit/C")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    T = URIRef("http://qudt.org/vocab/unit/T")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    K = URIRef("http://qudt.org/vocab/unit/K")
    S = URIRef("http://qudt.org/vocab/unit/S")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    S = URIRef("http://qudt.org/vocab/unit/S")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    T = URIRef("http://qudt.org/vocab/unit/T")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    V = URIRef("http://qudt.org/vocab/unit/V")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    H = URIRef("http://qudt.org/vocab/unit/H")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    B = URIRef("http://qudt.org/vocab/unit/B")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    W = URIRef("http://qudt.org/vocab/unit/W")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    N = URIRef("http://qudt.org/vocab/unit/N")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    B = URIRef("http://qudt.org/vocab/unit/B")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    J = URIRef("http://qudt.org/vocab/unit/J")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    C = URIRef("http://qudt.org/vocab/unit/C")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    W = URIRef("http://qudt.org/vocab/unit/W")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    G = URIRef("http://qudt.org/vocab/unit/G")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    C = URIRef("http://qudt.org/vocab/unit/C")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    L = URIRef("http://qudt.org/vocab/unit/L")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    N = URIRef("http://qudt.org/vocab/unit/N")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    T = URIRef("http://qudt.org/vocab/unit/T")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    V = URIRef("http://qudt.org/vocab/unit/V")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    G = URIRef("http://qudt.org/vocab/unit/G")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    V = URIRef("http://qudt.org/vocab/unit/V")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    A = URIRef("http://qudt.org/vocab/unit/A")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    A = URIRef("http://qudt.org/vocab/unit/A")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    R = URIRef("http://qudt.org/vocab/unit/R")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    N = URIRef("http://qudt.org/vocab/unit/N")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    N = URIRef("http://qudt.org/vocab/unit/N")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    S = URIRef("http://qudt.org/vocab/unit/S")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    P = URIRef("http://qudt.org/vocab/unit/P")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    G = URIRef("http://qudt.org/vocab/unit/G")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    V = URIRef("http://qudt.org/vocab/unit/V")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    C = URIRef("http://qudt.org/vocab/unit/C")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    U = URIRef("http://qudt.org/vocab/unit/U")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    A = URIRef("http://qudt.org/vocab/unit/A")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    B = URIRef("http://qudt.org/vocab/unit/B")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    W = URIRef("http://qudt.org/vocab/unit/W")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    C = URIRef("http://qudt.org/vocab/unit/C")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    M = URIRef("http://qudt.org/vocab/unit/M")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    H = URIRef("http://qudt.org/vocab/unit/H")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    K = URIRef("http://qudt.org/vocab/unit/K")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    S = URIRef("http://qudt.org/vocab/unit/S")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    K = URIRef("http://qudt.org/vocab/unit/K")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    M = URIRef("http://qudt.org/vocab/unit/M")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    N = URIRef("http://qudt.org/vocab/unit/N")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    N = URIRef("http://qudt.org/vocab/unit/N")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    MilloMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilloMOL-PER-L")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    K = URIRef("http://qudt.org/vocab/unit/K")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    J = URIRef("http://qudt.org/vocab/unit/J")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    K = URIRef("http://qudt.org/vocab/unit/K")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    N = URIRef("http://qudt.org/vocab/unit/N")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    T = URIRef("http://qudt.org/vocab/unit/T")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    C = URIRef("http://qudt.org/vocab/unit/C")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    R = URIRef("http://qudt.org/vocab/unit/R")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    K = URIRef("http://qudt.org/vocab/unit/K")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    J = URIRef("http://qudt.org/vocab/unit/J")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    K = URIRef("http://qudt.org/vocab/unit/K")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    E = URIRef("http://qudt.org/vocab/unit/E")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    K = URIRef("http://qudt.org/vocab/unit/K")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    S = URIRef("http://qudt.org/vocab/unit/S")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")

    _NS = Namespace("https://qudt.org/vocab/unit/")