from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class QUDT_KIND(DefinedNamespace):
    # Generated with namespacelib version 0.1.0
    _fail = True
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    PressureBasedMassFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMassFlow")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    DatasetOfBits = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBits")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    Log10Ratio = URIRef("http://qudt.org/vocab/quantitykind/Log10Ratio")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    EvaporativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransfer")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    RadioactiveDecay = URIRef("http://qudt.org/vocab/quantitykind/RadioactiveDecay")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    PressureBasedVolume = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolume")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    InverseTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseTime_Squared")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    NuclearQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/NuclearQuadrupoleMoment")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    PressureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVelocity")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    PressureInRelationToVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlowRate")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    LengthTemperatureTime = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperatureTime")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    TimePercentage = URIRef("http://qudt.org/vocab/quantitykind/TimePercentage")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    TransmissionRatioBetweenRotationAndTranslation = URIRef("http://qudt.org/vocab/quantitykind/TransmissionRatioBetweenRotationAndTranslation")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    VolumeDensityOfCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumeDensityOfCharge")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    DistanceTraveledDuringBurn = URIRef("http://qudt.org/vocab/quantitykind/DistanceTraveledDuringBurn")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarEnergy")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    TorquePerLength = URIRef("http://qudt.org/vocab/quantitykind/TorquePerLength")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    LinearElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCharge")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MechanicalImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalImpedance")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    EquilibriumConstantBasedOnConcentration = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnConcentration")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    RateOfChangeOfTemperature = URIRef("http://qudt.org/vocab/quantitykind/RateOfChangeOfTemperature")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricDipoleMoment_CubicPerEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_CubicPerEnergy_Squared")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MassRelatedElectricalCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassRelatedElectricalCurrent")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    DragForce = URIRef("http://qudt.org/vocab/quantitykind/DragForce")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    PowerConstant = URIRef("http://qudt.org/vocab/quantitykind/PowerConstant")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Energy_Squared = URIRef("http://qudt.org/vocab/quantitykind/Energy_Squared")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    BitRate = URIRef("http://qudt.org/vocab/quantitykind/BitRate")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MicrobialFormation = URIRef("http://qudt.org/vocab/quantitykind/MicrobialFormation")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    SignalDetectionThreshold = URIRef("http://qudt.org/vocab/quantitykind/SignalDetectionThreshold")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    EnergyPerMassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMassAmountOfSubstance")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    LogarithmRatioToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBase10")
    TemperatureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDensity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LineicResistance = URIRef("http://qudt.org/vocab/quantitykind/LineicResistance")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ActionTime = URIRef("http://qudt.org/vocab/quantitykind/ActionTime")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    PressureBasedMolality = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMolality")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    CombustionChamberTemperature = URIRef("http://qudt.org/vocab/quantitykind/CombustionChamberTemperature")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    TemperaturePerMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerMagneticFluxDensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    TotalPressure = URIRef("http://qudt.org/vocab/quantitykind/TotalPressure")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    OrbitalAngularMomentumPerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumPerUnitMass")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    PressureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedKinematicViscosity")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    DotsPerInch = URIRef("http://qudt.org/vocab/quantitykind/DotsPerInch")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    TemperatureAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/TemperatureAmountOfSubstance")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    ElectricCurrentPerAngle = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerAngle")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    TorsionalSpringConstant = URIRef("http://qudt.org/vocab/quantitykind/TorsionalSpringConstant")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PressureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedQuantity")
    HeartRate = URIRef("http://qudt.org/vocab/quantitykind/HeartRate")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    VolumetricEntityDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricEntityDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    TemperatureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMass")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    NeutronYieldPerFission = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerFission")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    PowerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerArea")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    BandwidthLengthProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthLengthProduct")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LengthPercentage = URIRef("http://qudt.org/vocab/quantitykind/LengthPercentage")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    AreaBitDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaBitDensity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    PressureBasedDensity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDensity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ExitPlaneTemperature = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneTemperature")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    RespiratoryRate = URIRef("http://qudt.org/vocab/quantitykind/RespiratoryRate")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    LineicLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LineicLogarithmicRatio")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    Gradient = URIRef("http://qudt.org/vocab/quantitykind/Gradient")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Polarizability = URIRef("http://qudt.org/vocab/quantitykind/Polarizability")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    ElectricDipoleMoment_QuarticPerEnergy_Cubic = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment_QuarticPerEnergy_Cubic")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    CostPerUnitPower = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitPower")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    BitTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/BitTransmissionRate")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    StandardAbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/StandardAbsoluteActivity")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    LagrangeFunction = URIRef("http://qudt.org/vocab/quantitykind/LagrangeFunction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    AreaMass = URIRef("http://qudt.org/vocab/quantitykind/AreaMass")
    TorquePerAngle = URIRef("http://qudt.org/vocab/quantitykind/TorquePerAngle")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    ActivityCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ActivityCoefficient")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    AreaTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTimeTemperature")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    NuclearEnergy = URIRef("http://qudt.org/vocab/quantitykind/NuclearEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    LineicTorque = URIRef("http://qudt.org/vocab/quantitykind/LineicTorque")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    VoltagePhasor = URIRef("http://qudt.org/vocab/quantitykind/VoltagePhasor")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    IsentropicCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsentropicCompressibility")
    InverseLengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseLengthTemperature")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    LorenzCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LorenzCoefficient")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    LengthMass = URIRef("http://qudt.org/vocab/quantitykind/LengthMass")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    RelativePressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RelativePressureCoefficient")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricCurrentPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitLength")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SoundPressure = URIRef("http://qudt.org/vocab/quantitykind/SoundPressure")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    LengthTemperature = URIRef("http://qudt.org/vocab/quantitykind/LengthTemperature")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MassConcentrationOfWaterVapour = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWaterVapour")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    RelativeLuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/RelativeLuminousFlux")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    PhotosyntheticPhotonFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFluxDensity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    VaporPermeability = URIRef("http://qudt.org/vocab/quantitykind/VaporPermeability")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    TotalMassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalMassStoppingPower")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/MomentumPerAngle")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    InverseTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTemperature")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AreaPerLength = URIRef("http://qudt.org/vocab/quantitykind/AreaPerLength")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LogarithmicMedianInformationFlow_SourceToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase10")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    PhotonIntensity = URIRef("http://qudt.org/vocab/quantitykind/PhotonIntensity")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    BandwidthDistanceProduct = URIRef("http://qudt.org/vocab/quantitykind/BandwidthDistanceProduct")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    TemperatureBasedMassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedMassFlowRate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    AngularMomentumPerAngle = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentumPerAngle")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    ExhaustGasMeanMolecularWeight = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasMeanMolecularWeight")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    ElectricChargeLinearDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLinearDensity")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AreicChargeDensityOrElectricFluxDensityOrElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/AreicChargeDensityOrElectricFluxDensityOrElectricPolarization")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MagnetizationField = URIRef("http://qudt.org/vocab/quantitykind/MagnetizationField")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    SecondOrderReactionRateConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondOrderReactionRateConstant")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    TrafficIntensity = URIRef("http://qudt.org/vocab/quantitykind/TrafficIntensity")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    WarmReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/WarmReceptorThreshold")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    ElectrolyticConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectrolyticConductivity")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    PressureBasedTemperature = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedTemperature")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    AbsoluteActivity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteActivity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    PressureBasedElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricCurrent")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MolarThermalCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarThermalCapacity")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    KermaRate = URIRef("http://qudt.org/vocab/quantitykind/KermaRate")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SpectralAngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralAngularCrossSection")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CutoffCurrentRating = URIRef("http://qudt.org/vocab/quantitykind/CutoffCurrentRating")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    PressureGradient = URIRef("http://qudt.org/vocab/quantitykind/PressureGradient")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    DigitRate = URIRef("http://qudt.org/vocab/quantitykind/DigitRate")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    PlanckFunction = URIRef("http://qudt.org/vocab/quantitykind/PlanckFunction")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Constringence = URIRef("http://qudt.org/vocab/quantitykind/Constringence")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    GruneisenParameter = URIRef("http://qudt.org/vocab/quantitykind/GruneisenParameter")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    EnergyPerSquareMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerSquareMagneticFluxDensity")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    FastFissionFactor = URIRef("http://qudt.org/vocab/quantitykind/FastFissionFactor")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    CurrentOfTheAmountOfSubtance = URIRef("http://qudt.org/vocab/quantitykind/CurrentOfTheAmountOfSubtance")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    TotalAtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalAtomicStoppingPower")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    VolumetricBitDensity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricBitDensity")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    VolumicAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/VolumicAmountOfSubstance")
    LengthByForce = URIRef("http://qudt.org/vocab/quantitykind/LengthByForce")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MaximumExpectedOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumExpectedOperatingPressure")
    ElectricalResistance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalResistance")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    TemporalSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/TemporalSummationFunction")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    TimeRelatedLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRelatedLogarithmicRatio")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    MassAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAbsorptionCoefficient")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    ModulusOfAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfAdmittance")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    VolumicOutput = URIRef("http://qudt.org/vocab/quantitykind/VolumicOutput")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    Kerma = URIRef("http://qudt.org/vocab/quantitykind/Kerma")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    CharacteristicAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicAcousticImpedance")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    MassStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/MassStoppingPower")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    TotalAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentum")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SoundPowerLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPowerLevel")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    MutualInductance = URIRef("http://qudt.org/vocab/quantitykind/MutualInductance")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    VolumicDataQuantity = URIRef("http://qudt.org/vocab/quantitykind/VolumicDataQuantity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    SpecificElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCharge")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/SquareEnergy")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    EffectiveExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/EffectiveExhaustVelocity")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    RadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyDensity")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    SpecificAcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/SpecificAcousticImpedance")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AreaRatio = URIRef("http://qudt.org/vocab/quantitykind/AreaRatio")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    SecondPolarMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondPolarMomentOfArea")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    TemperatureRelatedVolume = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedVolume")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    MechanicalTension = URIRef("http://qudt.org/vocab/quantitykind/MechanicalTension")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    LinearExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearExpansionCoefficient")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    RadiantEnergyExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergyExposure")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    ResistancePercentage = URIRef("http://qudt.org/vocab/quantitykind/ResistancePercentage")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ElectricCurrentPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitEnergy")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    MorbidityRate = URIRef("http://qudt.org/vocab/quantitykind/MorbidityRate")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    LineicPower = URIRef("http://qudt.org/vocab/quantitykind/LineicPower")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    Short_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Short-RangeOrderParameter")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    PressureBasedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedVolumeFlow")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    AcceptorDensity = URIRef("http://qudt.org/vocab/quantitykind/AcceptorDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    DensityInCombustionChamber = URIRef("http://qudt.org/vocab/quantitykind/DensityInCombustionChamber")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    EinsteinCoefficients = URIRef("http://qudt.org/vocab/quantitykind/EinsteinCoefficients")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    PolarMomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/PolarMomentOfInertia")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    MeltingPoint = URIRef("http://qudt.org/vocab/quantitykind/MeltingPoint")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    MassPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/MassPerElectricCharge")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    DoseEquivalentRate = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentRate")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    DimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/DimensionlessRatio")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    NapierianAbsorbance = URIRef("http://qudt.org/vocab/quantitykind/NapierianAbsorbance")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    SpectralRadiantEnergyDensityInTermsOfWavelength = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensityInTermsOfWavelength")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    IsothermalMoistureCapacity = URIRef("http://qudt.org/vocab/quantitykind/IsothermalMoistureCapacity")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    LinearBitDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearBitDensity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VentilationRatePerFloorArea = URIRef("http://qudt.org/vocab/quantitykind/VentilationRatePerFloorArea")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    SurgeImpedanceOfTheMedium = URIRef("http://qudt.org/vocab/quantitykind/SurgeImpedanceOfTheMedium")
    MassFraction = URIRef("http://qudt.org/vocab/quantitykind/MassFraction")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AmountOfSubstanceFraction = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFraction")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Reactivity = URIRef("http://qudt.org/vocab/quantitykind/Reactivity")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    EccentricityOfOrbit = URIRef("http://qudt.org/vocab/quantitykind/EccentricityOfOrbit")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    SpecificElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/SpecificElectricCurrent")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    DatasetOfBytes = URIRef("http://qudt.org/vocab/quantitykind/DatasetOfBytes")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    FailureRate = URIRef("http://qudt.org/vocab/quantitykind/FailureRate")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    SoilAdsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SoilAdsorptionCoefficient")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    MolarRefractivity = URIRef("http://qudt.org/vocab/quantitykind/MolarRefractivity")
    InformationContentExpressedAsALogarithmToBase2 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase2")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    EnergyPerTemperature = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerTemperature")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    DragCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DragCoefficient")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    TemperaturePerTime_Squared = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime_Squared")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ByteRate = URIRef("http://qudt.org/vocab/quantitykind/ByteRate")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ExtentOfReaction = URIRef("http://qudt.org/vocab/quantitykind/ExtentOfReaction")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    SpecificWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificWeight")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    BindingFraction = URIRef("http://qudt.org/vocab/quantitykind/BindingFraction")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    DebyeAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularWavenumber")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    AreicMass = URIRef("http://qudt.org/vocab/quantitykind/AreicMass")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LossAngle = URIRef("http://qudt.org/vocab/quantitykind/LossAngle")
    InitialExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/InitialExpansionRatio")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    Permeability = URIRef("http://qudt.org/vocab/quantitykind/Permeability")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    Period = URIRef("http://qudt.org/vocab/quantitykind/Period")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectricalConductance = URIRef("http://qudt.org/vocab/quantitykind/ElectricalConductance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Reluctance = URIRef("http://qudt.org/vocab/quantitykind/Reluctance")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    InverseMass = URIRef("http://qudt.org/vocab/quantitykind/InverseMass")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    LinearDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearDensity")
    Reflectivity = URIRef("http://qudt.org/vocab/quantitykind/Reflectivity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    InternalConversionFactor = URIRef("http://qudt.org/vocab/quantitykind/InternalConversionFactor")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    RiseOfOffStateVoltage = URIRef("http://qudt.org/vocab/quantitykind/RiseOfOffStateVoltage")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    Adaptation = URIRef("http://qudt.org/vocab/quantitykind/Adaptation")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    SpecificOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotatoryPower")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    PhaseSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/PhaseSpeedOfSound")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    PositivePlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PositivePlaneAngle")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    GeneralizedCoordinate = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedCoordinate")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    VolumeFlowRate_SurfaceRelated = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate_SurfaceRelated")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MolarAngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/MolarAngularMomentum")
    ElectricChargePerAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerAmountOfSubstance")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Dimensionless = URIRef("http://qudt.org/vocab/quantitykind/Dimensionless")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    BurstFactor = URIRef("http://qudt.org/vocab/quantitykind/BurstFactor")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    ForcePerLength = URIRef("http://qudt.org/vocab/quantitykind/ForcePerLength")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    ThrustToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToMassRatio")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ElectricField = URIRef("http://qudt.org/vocab/quantitykind/ElectricField")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    NozzleThroatPressure = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatPressure")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    LogOctanolAirPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolAirPartitionCoefficient")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MechanicalSurfaceImpedance = URIRef("http://qudt.org/vocab/quantitykind/MechanicalSurfaceImpedance")
    MOMENT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Y")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    LinearForce = URIRef("http://qudt.org/vocab/quantitykind/LinearForce")
    MagneticAreaMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticAreaMoment")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    EarthquakeMagnitude = URIRef("http://qudt.org/vocab/quantitykind/EarthquakeMagnitude")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    SpecificEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergyImparted")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    TemperatureGradient = URIRef("http://qudt.org/vocab/quantitykind/TemperatureGradient")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    WaterVapourPermeability = URIRef("http://qudt.org/vocab/quantitykind/WaterVapourPermeability")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    Flux = URIRef("http://qudt.org/vocab/quantitykind/Flux")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    MassicElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/MassicElectricCurrent")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    LogOctanolWaterPartitionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LogOctanolWaterPartitionCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ModulusOfRotationalSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfRotationalSubgradeReaction")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    Concentration = URIRef("http://qudt.org/vocab/quantitykind/Concentration")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    WebTimeAveragePressure = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAveragePressure")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    PhotonLuminance = URIRef("http://qudt.org/vocab/quantitykind/PhotonLuminance")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    FissionMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionMultiplicationFactor")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    AngularReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/AngularReciprocalLatticeVector")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    TemperatureBasedVolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVolumeFlowRate")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    MultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/MultiplicationFactor")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    MassRatioOfWaterToDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterToDryMatter")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    PeltierCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PeltierCoefficient")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    AmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentration")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    FahrenheitTemperature = URIRef("http://qudt.org/vocab/quantitykind/FahrenheitTemperature")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    RadiantFluence = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluence")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Radioactivity = URIRef("http://qudt.org/vocab/quantitykind/Radioactivity")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TransmittanceDensity = URIRef("http://qudt.org/vocab/quantitykind/TransmittanceDensity")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    ReciprocalVoltage = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalVoltage")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    MassConcentrationOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassConcentrationOfWater")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    LuminousEnergy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEnergy")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    VolumetricHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/VolumetricHeatCapacity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    EllipticalOrbitPerigeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitPerigeeVelocity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    MagneticFluxDensityOrMagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensityOrMagneticPolarization")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    FishBiotransformationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/FishBiotransformationHalfLife")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    KineticOrThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticOrThermalEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    ThrustCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThrustCoefficient")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PressureBasedElectricVoltage = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedElectricVoltage")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    PartialPressure = URIRef("http://qudt.org/vocab/quantitykind/PartialPressure")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    InversePermittivity = URIRef("http://qudt.org/vocab/quantitykind/InversePermittivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    MagneticSusceptability = URIRef("http://qudt.org/vocab/quantitykind/MagneticSusceptability")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    ReflectanceFactor = URIRef("http://qudt.org/vocab/quantitykind/ReflectanceFactor")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    DensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/DensityOfStates")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Piece = URIRef("http://qudt.org/vocab/quantitykind/Piece")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    HeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/HeadEndPressure")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    TimeConstant_Inductance = URIRef("http://qudt.org/vocab/quantitykind/TimeConstant_Inductance")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    GeneralizedForce = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedForce")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    RelativePartialPressure = URIRef("http://qudt.org/vocab/quantitykind/RelativePartialPressure")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    EvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/EvaporativeHeatTransferCoefficient")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    ConvectiveHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/ConvectiveHeatTransfer")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SpecificEnthalpy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnthalpy")
    NeutronYieldPerAbsorption = URIRef("http://qudt.org/vocab/quantitykind/NeutronYieldPerAbsorption")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    TotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/TotalCrossSection")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    ThermodynamicEntropy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEntropy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    AmountOfSubstanceConcentrationOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceConcentrationOfB")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    LoudnessLevel = URIRef("http://qudt.org/vocab/quantitykind/LoudnessLevel")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MolarHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MolarHeatCapacity")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    ExposureOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureOfIonizingRadiation")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    DecayConstant = URIRef("http://qudt.org/vocab/quantitykind/DecayConstant")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    MagneticFluxPerUnitLength = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxPerUnitLength")
    MobilityRatio = URIRef("http://qudt.org/vocab/quantitykind/MobilityRatio")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    Population = URIRef("http://qudt.org/vocab/quantitykind/Population")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    PressureInRelationToVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/PressureInRelationToVolumeFlow")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    ElectricalPowerToMassRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectricalPowerToMassRatio")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Incidence = URIRef("http://qudt.org/vocab/quantitykind/Incidence")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PRODUCT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Z")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    RelativeMassDensity = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDensity")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ByteDataVolume = URIRef("http://qudt.org/vocab/quantitykind/ByteDataVolume")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AreaTemperature = URIRef("http://qudt.org/vocab/quantitykind/AreaTemperature")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    Magnetization = URIRef("http://qudt.org/vocab/quantitykind/Magnetization")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    Basicity = URIRef("http://qudt.org/vocab/quantitykind/Basicity")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    AreicTorque = URIRef("http://qudt.org/vocab/quantitykind/AreicTorque")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PressureLossPerLength = URIRef("http://qudt.org/vocab/quantitykind/PressureLossPerLength")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Turbidity = URIRef("http://qudt.org/vocab/quantitykind/Turbidity")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    InverseEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    MagneticTension = URIRef("http://qudt.org/vocab/quantitykind/MagneticTension")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    SurfaceActivityDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceActivityDensity")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    InversePressure = URIRef("http://qudt.org/vocab/quantitykind/InversePressure")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EquivalenceDoseOutput = URIRef("http://qudt.org/vocab/quantitykind/EquivalenceDoseOutput")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    PowerPerArea = URIRef("http://qudt.org/vocab/quantitykind/PowerPerArea")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    SecondRadiationConstant = URIRef("http://qudt.org/vocab/quantitykind/SecondRadiationConstant")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    TorsionalRigidity = URIRef("http://qudt.org/vocab/quantitykind/TorsionalRigidity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    ResistanceBasedInductance = URIRef("http://qudt.org/vocab/quantitykind/ResistanceBasedInductance")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    MassAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstance")
    BoilingPoint = URIRef("http://qudt.org/vocab/quantitykind/BoilingPoint")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EquilibriumConstantBasedOnPressure = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantBasedOnPressure")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    InverseAmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/InverseAmountOfSubstance")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ElectronMobility = URIRef("http://qudt.org/vocab/quantitykind/ElectronMobility")
    LineicCharge = URIRef("http://qudt.org/vocab/quantitykind/LineicCharge")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    LinearTorque = URIRef("http://qudt.org/vocab/quantitykind/LinearTorque")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    LogarithmicMedianInformationFlow_SourceToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBaseE")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    GeneralizedVelocity = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedVelocity")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Acidity = URIRef("http://qudt.org/vocab/quantitykind/Acidity")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    SpecificGibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificGibbsEnergy")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    OlfactoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/OlfactoryThreshold")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Count = URIRef("http://qudt.org/vocab/quantitykind/Count")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ThermalResistivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistivity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ResonanceEscapeProbability = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbability")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    InformationContentExpressedAsALogarithmToBaseE = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBaseE")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    SpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/SpinQuantumNumber")
    LossFactor = URIRef("http://qudt.org/vocab/quantitykind/LossFactor")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MagneticPolarization = URIRef("http://qudt.org/vocab/quantitykind/MagneticPolarization")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    ThrusterPowerToThrustEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThrusterPowerToThrustEfficiency")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    CharacteristicVelocity = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicVelocity")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    DisplacementCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrentDensity")
    TouchThresholds = URIRef("http://qudt.org/vocab/quantitykind/TouchThresholds")
    VolumeThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/VolumeThermalExpansion")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MASS_PROPERTY_UNCERTAINTY = URIRef("http://qudt.org/vocab/quantitykind/MASS-PROPERTY-UNCERTAINTY")
    MolalityOfSolute = URIRef("http://qudt.org/vocab/quantitykind/MolalityOfSolute")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    Spin = URIRef("http://qudt.org/vocab/quantitykind/Spin")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    StochasticProcess = URIRef("http://qudt.org/vocab/quantitykind/StochasticProcess")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    ElectromagneticPermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeabilityRatio")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    PhotonRadiance = URIRef("http://qudt.org/vocab/quantitykind/PhotonRadiance")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    PhotoThresholdOfAwarenessFunction = URIRef("http://qudt.org/vocab/quantitykind/PhotoThresholdOfAwarenessFunction")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    CubicElectricDipoleMomentPerSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/CubicElectricDipoleMomentPerSquareEnergy")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    InverseSquareEnergy = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareEnergy")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    ForcePerAngle = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAngle")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Solubility_Water = URIRef("http://qudt.org/vocab/quantitykind/Solubility_Water")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    Time_Squared = URIRef("http://qudt.org/vocab/quantitykind/Time_Squared")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    SoundExposure = URIRef("http://qudt.org/vocab/quantitykind/SoundExposure")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Radiance = URIRef("http://qudt.org/vocab/quantitykind/Radiance")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    SpecificPower = URIRef("http://qudt.org/vocab/quantitykind/SpecificPower")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    ReciprocalElectricResistance = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalElectricResistance")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    HallCoefficient = URIRef("http://qudt.org/vocab/quantitykind/HallCoefficient")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LuminousExitance = URIRef("http://qudt.org/vocab/quantitykind/LuminousExitance")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    BioconcentrationFactor = URIRef("http://qudt.org/vocab/quantitykind/BioconcentrationFactor")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    EnergyExpenditure = URIRef("http://qudt.org/vocab/quantitykind/EnergyExpenditure")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    RF_Power = URIRef("http://qudt.org/vocab/quantitykind/RF-Power")
    SectionAreaIntegral = URIRef("http://qudt.org/vocab/quantitykind/SectionAreaIntegral")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    MolarDensity = URIRef("http://qudt.org/vocab/quantitykind/MolarDensity")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Reflectance = URIRef("http://qudt.org/vocab/quantitykind/Reflectance")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    LinearIonization = URIRef("http://qudt.org/vocab/quantitykind/LinearIonization")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ThermalCoefficientOfLinearExpansion = URIRef("http://qudt.org/vocab/quantitykind/ThermalCoefficientOfLinearExpansion")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    NozzleThroatCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatCrossSectionalArea")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    AngularCrossSection = URIRef("http://qudt.org/vocab/quantitykind/AngularCrossSection")
    ReciprocalPlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalPlaneAngle")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    quantitykind = URIRef("http://qudt.org/vocab/quantitykind")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    PrincipalQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/PrincipalQuantumNumber")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    VideoFrameRate = URIRef("http://qudt.org/vocab/quantitykind/VideoFrameRate")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    LinearVoltageCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearVoltageCoefficient")
    MaxSeaLevelThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxSeaLevelThrust")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    InverseSquareMass = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareMass")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    RotaryShock = URIRef("http://qudt.org/vocab/quantitykind/RotaryShock")
    SpecificOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/SpecificOpticalRotationalAbility")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LinearStrain = URIRef("http://qudt.org/vocab/quantitykind/LinearStrain")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    DoseEquivalentQualityFactor = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalentQualityFactor")
    TotalIonization = URIRef("http://qudt.org/vocab/quantitykind/TotalIonization")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    LengthPerUnitElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LengthPerUnitElectricCurrent")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ShearStrain = URIRef("http://qudt.org/vocab/quantitykind/ShearStrain")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    AreicEnergyFlow = URIRef("http://qudt.org/vocab/quantitykind/AreicEnergyFlow")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    InformationFlowRate = URIRef("http://qudt.org/vocab/quantitykind/InformationFlowRate")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    StressOpticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StressOpticCoefficient")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    MagneticReluctivity = URIRef("http://qudt.org/vocab/quantitykind/MagneticReluctivity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    PressurePercentage = URIRef("http://qudt.org/vocab/quantitykind/PressurePercentage")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    Debye_WallerFactor = URIRef("http://qudt.org/vocab/quantitykind/Debye-WallerFactor")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    LuminousFluxPerArea = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxPerArea")
    OsmoticCoefficient = URIRef("http://qudt.org/vocab/quantitykind/OsmoticCoefficient")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    NumberOfParticles = URIRef("http://qudt.org/vocab/quantitykind/NumberOfParticles")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AbsorbedDoseRate = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDoseRate")
    ExposureRateOfIonizingRadiation = URIRef("http://qudt.org/vocab/quantitykind/ExposureRateOfIonizingRadiation")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    Non_LeakageProbability = URIRef("http://qudt.org/vocab/quantitykind/Non-LeakageProbability")
    InformationContentExpressedAsALogarithmToBase10 = URIRef("http://qudt.org/vocab/quantitykind/InformationContentExpressedAsALogarithmToBase10")
    InverseMagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/InverseMagneticFlux")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MortalityRate = URIRef("http://qudt.org/vocab/quantitykind/MortalityRate")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MolarOpticalRotationalAbility = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotationalAbility")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    FermiTemperature = URIRef("http://qudt.org/vocab/quantitykind/FermiTemperature")
    AverageHeadEndPressure = URIRef("http://qudt.org/vocab/quantitykind/AverageHeadEndPressure")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    LineicMass = URIRef("http://qudt.org/vocab/quantitykind/LineicMass")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    SpecificSurfaceArea = URIRef("http://qudt.org/vocab/quantitykind/SpecificSurfaceArea")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    HeatFlowRatePerUnitArea = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRatePerUnitArea")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    RateOfRiseOfVoltage = URIRef("http://qudt.org/vocab/quantitykind/RateOfRiseOfVoltage")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    SoundVolumeVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundVolumeVelocity")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    FermiAngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/FermiAngularWavenumber")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    ReynoldsNumber = URIRef("http://qudt.org/vocab/quantitykind/ReynoldsNumber")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    StaticFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/StaticFrictionCoefficient")
    FloatingPointCalculationCapability = URIRef("http://qudt.org/vocab/quantitykind/FloatingPointCalculationCapability")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    AmountOfSubstancePerUnitMassPressure = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMassPressure")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ChemicalConsumptionPerMass = URIRef("http://qudt.org/vocab/quantitykind/ChemicalConsumptionPerMass")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    SphericalIlluminance = URIRef("http://qudt.org/vocab/quantitykind/SphericalIlluminance")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ParticleCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrentDensity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    Curvature = URIRef("http://qudt.org/vocab/quantitykind/Curvature")
    Action = URIRef("http://qudt.org/vocab/quantitykind/Action")
    SoundExposureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundExposureLevel")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    ElectricChargeLineDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeLineDensity")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    ForcePerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ForcePerElectricCharge")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    DiastolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/DiastolicBloodPressure")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    SerumOrPlasmaLevel = URIRef("http://qudt.org/vocab/quantitykind/SerumOrPlasmaLevel")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    RelativeAtomicMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeAtomicMass")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    OrderOfReflection = URIRef("http://qudt.org/vocab/quantitykind/OrderOfReflection")
    PermeabilityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermeabilityRatio")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    ElectricChargeSurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeSurfaceDensity")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    VoltageRatio = URIRef("http://qudt.org/vocab/quantitykind/VoltageRatio")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    LeakageFactor = URIRef("http://qudt.org/vocab/quantitykind/LeakageFactor")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    LuminousIntensity = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensity")
    StructuralEfficiency = URIRef("http://qudt.org/vocab/quantitykind/StructuralEfficiency")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    INERT_MASS = URIRef("http://qudt.org/vocab/quantitykind/INERT-MASS")
    WaterVaporDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/WaterVaporDiffusionCoefficient")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    TimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/TimeTemperature")
    Tension = URIRef("http://qudt.org/vocab/quantitykind/Tension")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    DynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/DynamicViscosity")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    IntinsicCarrierDensity = URIRef("http://qudt.org/vocab/quantitykind/IntinsicCarrierDensity")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    UpperCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/UpperCriticalMagneticFluxDensity")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    ThrustToWeightRatio = URIRef("http://qudt.org/vocab/quantitykind/ThrustToWeightRatio")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    DynamicFrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DynamicFrictionCoefficient")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    InverseMass_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseMass_Squared")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    AverageSpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/AverageSpecificImpulse")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    SpectralConcentrationOfRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfRadiantEnergyDensity")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    MassTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassTemperature")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    AmbientPressure = URIRef("http://qudt.org/vocab/quantitykind/AmbientPressure")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Coercivity = URIRef("http://qudt.org/vocab/quantitykind/Coercivity")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    ScalarMagneticPotential = URIRef("http://qudt.org/vocab/quantitykind/ScalarMagneticPotential")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    Capacity = URIRef("http://qudt.org/vocab/quantitykind/Capacity")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    TemperatureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedDynamicViscosity")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    PressureBurningRateIndex = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateIndex")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    EquilibriumConstantOnPressureBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnPressureBasis")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    SecondStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SecondStageMassRatio")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    FundamentalReciprocalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalReciprocalLatticeVector")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    SpeedOfLight = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfLight")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    AverageLogarithmicEnergyDecrement = URIRef("http://qudt.org/vocab/quantitykind/AverageLogarithmicEnergyDecrement")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    EnergyPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerElectricCharge")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ElectricChargePerArea = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerArea")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    Prevalence = URIRef("http://qudt.org/vocab/quantitykind/Prevalence")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    TotalCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrentDensity")
    LinearElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrent")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    Mobility = URIRef("http://qudt.org/vocab/quantitykind/Mobility")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    PoyntingVector = URIRef("http://qudt.org/vocab/quantitykind/PoyntingVector")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    PowerPerAreaQuarticTemperature = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaQuarticTemperature")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    LogarithmicMedianInformationFlow_SourceToBase2 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicMedianInformationFlow_SourceToBase2")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    QuantityOfLight = URIRef("http://qudt.org/vocab/quantitykind/QuantityOfLight")
    MechanicalMobility = URIRef("http://qudt.org/vocab/quantitykind/MechanicalMobility")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    SecondMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondMomentOfArea")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    ActiveEnergy = URIRef("http://qudt.org/vocab/quantitykind/ActiveEnergy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    CanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/CanonicalPartitionFunction")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    AreaChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/AreaChargeDensity")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    ThermalUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactor")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    CharacteristicNumber = URIRef("http://qudt.org/vocab/quantitykind/CharacteristicNumber")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    ActivePower = URIRef("http://qudt.org/vocab/quantitykind/ActivePower")
    ElectromagneticWavePhaseSpeed = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticWavePhaseSpeed")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    DebyeTemperature = URIRef("http://qudt.org/vocab/quantitykind/DebyeTemperature")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LinearMass = URIRef("http://qudt.org/vocab/quantitykind/LinearMass")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    NuclearSpinQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/NuclearSpinQuantumNumber")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    SurfaceRelatedVolumeFlow = URIRef("http://qudt.org/vocab/quantitykind/SurfaceRelatedVolumeFlow")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    ComplexPower = URIRef("http://qudt.org/vocab/quantitykind/ComplexPower")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Weight = URIRef("http://qudt.org/vocab/quantitykind/Weight")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    InverseTime = URIRef("http://qudt.org/vocab/quantitykind/InverseTime")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    AtomicEnergy = URIRef("http://qudt.org/vocab/quantitykind/AtomicEnergy")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    AreaThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/AreaThermalExpansion")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    Impulse = URIRef("http://qudt.org/vocab/quantitykind/Impulse")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    HydraulicPermeability = URIRef("http://qudt.org/vocab/quantitykind/HydraulicPermeability")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    MolecularMass = URIRef("http://qudt.org/vocab/quantitykind/MolecularMass")
    AngularMomentum = URIRef("http://qudt.org/vocab/quantitykind/AngularMomentum")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    NeutralRatio = URIRef("http://qudt.org/vocab/quantitykind/NeutralRatio")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    InitialVelocity = URIRef("http://qudt.org/vocab/quantitykind/InitialVelocity")
    Capacitance = URIRef("http://qudt.org/vocab/quantitykind/Capacitance")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    NeutronDiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionCoefficient")
    RecombinationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/RecombinationCoefficient")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MaximumOperatingPressure = URIRef("http://qudt.org/vocab/quantitykind/MaximumOperatingPressure")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    ModulusOfImpedance = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfImpedance")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    NeutronDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/NeutronDiffusionLength")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    TemperatureRateOfChange = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRateOfChange")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    GFactorOfNucleus = URIRef("http://qudt.org/vocab/quantitykind/GFactorOfNucleus")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    MassicPower = URIRef("http://qudt.org/vocab/quantitykind/MassicPower")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    IonConcentration = URIRef("http://qudt.org/vocab/quantitykind/IonConcentration")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    ModulusOfSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfSubgradeReaction")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    MagneticVectorPotential = URIRef("http://qudt.org/vocab/quantitykind/MagneticVectorPotential")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    LatticePlaneSpacing = URIRef("http://qudt.org/vocab/quantitykind/LatticePlaneSpacing")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    LinearResistance = URIRef("http://qudt.org/vocab/quantitykind/LinearResistance")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    ExhaustGasesSpecificHeat = URIRef("http://qudt.org/vocab/quantitykind/ExhaustGasesSpecificHeat")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    PolarizationField = URIRef("http://qudt.org/vocab/quantitykind/PolarizationField")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    SingleStageLauncherMassRatio = URIRef("http://qudt.org/vocab/quantitykind/SingleStageLauncherMassRatio")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AcousticImpedance = URIRef("http://qudt.org/vocab/quantitykind/AcousticImpedance")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    AreaAngle = URIRef("http://qudt.org/vocab/quantitykind/AreaAngle")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    Thrust = URIRef("http://qudt.org/vocab/quantitykind/Thrust")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MoleFraction = URIRef("http://qudt.org/vocab/quantitykind/MoleFraction")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    VolumetricOutputPower = URIRef("http://qudt.org/vocab/quantitykind/VolumetricOutputPower")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Slowing_DownLength = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownLength")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    LinearElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/LinearElectricCurrentDensity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    DELTA_V = URIRef("http://qudt.org/vocab/quantitykind/DELTA-V")
    GyromagneticRatio = URIRef("http://qudt.org/vocab/quantitykind/GyromagneticRatio")
    AverageVacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/AverageVacuumThrust")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    DryVolume = URIRef("http://qudt.org/vocab/quantitykind/DryVolume")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    Compressibility = URIRef("http://qudt.org/vocab/quantitykind/Compressibility")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    SpecificEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEnergy")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    AreaTime = URIRef("http://qudt.org/vocab/quantitykind/AreaTime")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    ThermalDiffusionRatio = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatio")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    ParticleSourceDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleSourceDensity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    Angle = URIRef("http://qudt.org/vocab/quantitykind/Angle")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    EquilibriumConstantOnConcentrationBasis = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstantOnConcentrationBasis")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    StoichiometricNumber = URIRef("http://qudt.org/vocab/quantitykind/StoichiometricNumber")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Luminance = URIRef("http://qudt.org/vocab/quantitykind/Luminance")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    Length = URIRef("http://qudt.org/vocab/quantitykind/Length")
    ByteTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/ByteTransmissionRate")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    MassConcentration = URIRef("http://qudt.org/vocab/quantitykind/MassConcentration")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    RichardsonConstant = URIRef("http://qudt.org/vocab/quantitykind/RichardsonConstant")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    NozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/NozzleThroatDiameter")
    IonDensity = URIRef("http://qudt.org/vocab/quantitykind/IonDensity")
    NumberDensity = URIRef("http://qudt.org/vocab/quantitykind/NumberDensity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    RelativeMassExcess = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassExcess")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    InverseEnergy_Squared = URIRef("http://qudt.org/vocab/quantitykind/InverseEnergy_Squared")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    GeneFamilyAbundance = URIRef("http://qudt.org/vocab/quantitykind/GeneFamilyAbundance")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    MagneticDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMoment")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    PRODUCT_OF_INERTIA_X = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_X")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    ForcePerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/ForcePerAreaTime")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    AtmosphericPressure = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericPressure")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    FlightPathAngle = URIRef("http://qudt.org/vocab/quantitykind/FlightPathAngle")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    RocketAtmosphericTransverseForce = URIRef("http://qudt.org/vocab/quantitykind/RocketAtmosphericTransverseForce")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    CurvatureFromRadius = URIRef("http://qudt.org/vocab/quantitykind/CurvatureFromRadius")
    Vorticity = URIRef("http://qudt.org/vocab/quantitykind/Vorticity")
    CoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/CoefficientOfHeatTransfer")
    ForceConstant = URIRef("http://qudt.org/vocab/quantitykind/ForceConstant")
    DonorDensity = URIRef("http://qudt.org/vocab/quantitykind/DonorDensity")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    GroupSpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/GroupSpeedOfSound")
    Repetency = URIRef("http://qudt.org/vocab/quantitykind/Repetency")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    DynamicPressure = URIRef("http://qudt.org/vocab/quantitykind/DynamicPressure")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    Voltage = URIRef("http://qudt.org/vocab/quantitykind/Voltage")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    Activity = URIRef("http://qudt.org/vocab/quantitykind/Activity")
    HyperfineStructureQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/HyperfineStructureQuantumNumber")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    ElectricCurrentPerUnitTemperature = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPerUnitTemperature")
    KinematicViscosityOrDiffusionConstantOrThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosityOrDiffusionConstantOrThermalDiffusivity")
    MassOfTheEarth = URIRef("http://qudt.org/vocab/quantitykind/MassOfTheEarth")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    LinearPower = URIRef("http://qudt.org/vocab/quantitykind/LinearPower")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    DegreeOfDissociation = URIRef("http://qudt.org/vocab/quantitykind/DegreeOfDissociation")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ElectricFieldStrength = URIRef("http://qudt.org/vocab/quantitykind/ElectricFieldStrength")
    StandardChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/StandardChemicalPotential")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    EnergyContent = URIRef("http://qudt.org/vocab/quantitykind/EnergyContent")
    ThermalTransmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalTransmittance")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    OsmoticPressure = URIRef("http://qudt.org/vocab/quantitykind/OsmoticPressure")
    Radiosity = URIRef("http://qudt.org/vocab/quantitykind/Radiosity")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    QualityFactor = URIRef("http://qudt.org/vocab/quantitykind/QualityFactor")
    TimeSquared = URIRef("http://qudt.org/vocab/quantitykind/TimeSquared")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    ResonanceEnergy = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEnergy")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    RelativeMassRatioOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassRatioOfVapour")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    EinsteinTransitionProbability = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbability")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    TotalRadiance = URIRef("http://qudt.org/vocab/quantitykind/TotalRadiance")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ReciprocalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReciprocalEnergy")
    GustatoryThreshold = URIRef("http://qudt.org/vocab/quantitykind/GustatoryThreshold")
    PowerFactor = URIRef("http://qudt.org/vocab/quantitykind/PowerFactor")
    RankineTemperature = URIRef("http://qudt.org/vocab/quantitykind/RankineTemperature")
    ThermalConductivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductivity")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    PowerAreaPerSolidAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerAreaPerSolidAngle")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    DynamicFriction = URIRef("http://qudt.org/vocab/quantitykind/DynamicFriction")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    VolumePerUnitTime = URIRef("http://qudt.org/vocab/quantitykind/VolumePerUnitTime")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    ParticleFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluenceRate")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    VisionThresholds = URIRef("http://qudt.org/vocab/quantitykind/VisionThresholds")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    Susceptance = URIRef("http://qudt.org/vocab/quantitykind/Susceptance")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    Circulation = URIRef("http://qudt.org/vocab/quantitykind/Circulation")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    StressIntensityFactor = URIRef("http://qudt.org/vocab/quantitykind/StressIntensityFactor")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    SpecificImpulseByWeight = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByWeight")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    PressureCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PressureCoefficient")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    TemperatureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedLength")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Long_RangeOrderParameter = URIRef("http://qudt.org/vocab/quantitykind/Long-RangeOrderParameter")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    MigrationArea = URIRef("http://qudt.org/vocab/quantitykind/MigrationArea")
    BulkModulus = URIRef("http://qudt.org/vocab/quantitykind/BulkModulus")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    CrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/CrossSectionalArea")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    RadialDistance = URIRef("http://qudt.org/vocab/quantitykind/RadialDistance")
    FrictionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/FrictionCoefficient")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    StatisticalWeight = URIRef("http://qudt.org/vocab/quantitykind/StatisticalWeight")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    StrainEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/StrainEnergyDensity")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MolarAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAttenuationCoefficient")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    LiftForce = URIRef("http://qudt.org/vocab/quantitykind/LiftForce")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    ExchangeIntegral = URIRef("http://qudt.org/vocab/quantitykind/ExchangeIntegral")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    PayloadRatio = URIRef("http://qudt.org/vocab/quantitykind/PayloadRatio")
    CubicExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CubicExpansionCoefficient")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    IncidenceProportion = URIRef("http://qudt.org/vocab/quantitykind/IncidenceProportion")
    LinearAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAbsorptionCoefficient")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    Permeance = URIRef("http://qudt.org/vocab/quantitykind/Permeance")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    TemperatureDifference = URIRef("http://qudt.org/vocab/quantitykind/TemperatureDifference")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    PropellantTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantTemperature")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    EquilibriumConstant = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumConstant")
    Pressure = URIRef("http://qudt.org/vocab/quantitykind/Pressure")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    AmountOfSubstancePerUnitVolume = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitVolume")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ElectromagneticEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticEnergyDensity")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    AmountOfSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstance")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    IsentropicExponent = URIRef("http://qudt.org/vocab/quantitykind/IsentropicExponent")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    LengthRatio = URIRef("http://qudt.org/vocab/quantitykind/LengthRatio")
    ElectricPotential = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotential")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    Efficiency = URIRef("http://qudt.org/vocab/quantitykind/Efficiency")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    CenterOfGravity_Z = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Z")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Log10FrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/Log10FrequencyInterval")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    ElectromotiveForce = URIRef("http://qudt.org/vocab/quantitykind/ElectromotiveForce")
    MassicTorque = URIRef("http://qudt.org/vocab/quantitykind/MassicTorque")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    ParticleCurrent = URIRef("http://qudt.org/vocab/quantitykind/ParticleCurrent")
    ElectricFlux = URIRef("http://qudt.org/vocab/quantitykind/ElectricFlux")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ElectricChargePerMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargePerMass")
    BurnRate = URIRef("http://qudt.org/vocab/quantitykind/BurnRate")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    AreaPerTime = URIRef("http://qudt.org/vocab/quantitykind/AreaPerTime")
    RelaxationTIme = URIRef("http://qudt.org/vocab/quantitykind/RelaxationTIme")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    LinearLogarithmicRatio = URIRef("http://qudt.org/vocab/quantitykind/LinearLogarithmicRatio")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    MolarEntropy = URIRef("http://qudt.org/vocab/quantitykind/MolarEntropy")
    MOMENT_OF_INERTIA_Z = URIRef("http://qudt.org/vocab/quantitykind/MOMENT-OF-INERTIA_Z")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    CorrelatedColorTemperature = URIRef("http://qudt.org/vocab/quantitykind/CorrelatedColorTemperature")
    ThermalConductance = URIRef("http://qudt.org/vocab/quantitykind/ThermalConductance")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    IonicStrength = URIRef("http://qudt.org/vocab/quantitykind/IonicStrength")
    LineicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/LineicDataVolume")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    ExitPlaneCrossSectionalArea = URIRef("http://qudt.org/vocab/quantitykind/ExitPlaneCrossSectionalArea")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MolarFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MolarFlowRate")
    SpecificHeatPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatPressure")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    BurgersVector = URIRef("http://qudt.org/vocab/quantitykind/BurgersVector")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    MassicActivity = URIRef("http://qudt.org/vocab/quantitykind/MassicActivity")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    SurfaceDensity = URIRef("http://qudt.org/vocab/quantitykind/SurfaceDensity")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    ModulusOfLinearSubgradeReaction = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfLinearSubgradeReaction")
    SunProtectionFactorOfAProduct = URIRef("http://qudt.org/vocab/quantitykind/SunProtectionFactorOfAProduct")
    ExitPlanePressure = URIRef("http://qudt.org/vocab/quantitykind/ExitPlanePressure")
    MassFractionOfWater = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfWater")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    MagnetomotiveForce = URIRef("http://qudt.org/vocab/quantitykind/MagnetomotiveForce")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    MassAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassAttenuationCoefficient")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    CostPerArea = URIRef("http://qudt.org/vocab/quantitykind/CostPerArea")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    EnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/EnergyImparted")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    NeelTemperature = URIRef("http://qudt.org/vocab/quantitykind/NeelTemperature")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    WarpingConstant = URIRef("http://qudt.org/vocab/quantitykind/WarpingConstant")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    MagneticField = URIRef("http://qudt.org/vocab/quantitykind/MagneticField")
    DisplacementVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/DisplacementVectorOfIon")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/RadiantEnergy")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    IgnitionIntervalTime = URIRef("http://qudt.org/vocab/quantitykind/IgnitionIntervalTime")
    SpecificHeatCapacityAtSaturation = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtSaturation")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    Momentum = URIRef("http://qudt.org/vocab/quantitykind/Momentum")
    Resistivity = URIRef("http://qudt.org/vocab/quantitykind/Resistivity")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    HeatCapacityRatio = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacityRatio")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    MassPerTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerTime")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    ElectricDipoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricDipoleMoment")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    ElectricPolarization = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarization")
    SoundPressureLevel = URIRef("http://qudt.org/vocab/quantitykind/SoundPressureLevel")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    LatticeVector = URIRef("http://qudt.org/vocab/quantitykind/LatticeVector")
    RadianceFactor = URIRef("http://qudt.org/vocab/quantitykind/RadianceFactor")
    ParticleNumberDensity = URIRef("http://qudt.org/vocab/quantitykind/ParticleNumberDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    PREDICTED_MASS = URIRef("http://qudt.org/vocab/quantitykind/PREDICTED-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    CENTER_OF_MASS = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-MASS")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    LogarithmicFrequencyInterval = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyInterval")
    PhotosyntheticPhotonFlux = URIRef("http://qudt.org/vocab/quantitykind/PhotosyntheticPhotonFlux")
    VolumetricElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/VolumetricElectricCharge")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    Conductivity = URIRef("http://qudt.org/vocab/quantitykind/Conductivity")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ExpansionRatio = URIRef("http://qudt.org/vocab/quantitykind/ExpansionRatio")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    PressureBurningRateConstant = URIRef("http://qudt.org/vocab/quantitykind/PressureBurningRateConstant")
    TemperatureBasedVelocity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedVelocity")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    TemperaturePerTime = URIRef("http://qudt.org/vocab/quantitykind/TemperaturePerTime")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    MassRatioOfWaterVapourToDryGas = URIRef("http://qudt.org/vocab/quantitykind/MassRatioOfWaterVapourToDryGas")
    WebTimeAverageThrust = URIRef("http://qudt.org/vocab/quantitykind/WebTimeAverageThrust")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    AuxillaryMagneticField = URIRef("http://qudt.org/vocab/quantitykind/AuxillaryMagneticField")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    AreicDataVolume = URIRef("http://qudt.org/vocab/quantitykind/AreicDataVolume")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    LuminousIntensityDistribution = URIRef("http://qudt.org/vocab/quantitykind/LuminousIntensityDistribution")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    ThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicEnergy")
    SpecificModulus = URIRef("http://qudt.org/vocab/quantitykind/SpecificModulus")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    Slowing_DownDensity = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownDensity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    MassRatio = URIRef("http://qudt.org/vocab/quantitykind/MassRatio")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    EnergyKinetic = URIRef("http://qudt.org/vocab/quantitykind/EnergyKinetic")
    MotorConstant = URIRef("http://qudt.org/vocab/quantitykind/MotorConstant")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    MassEnergyTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MassEnergyTransferCoefficient")
    InverseSquareTime = URIRef("http://qudt.org/vocab/quantitykind/InverseSquareTime")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    SoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/SoundIntensity")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    MeanLinearRange = URIRef("http://qudt.org/vocab/quantitykind/MeanLinearRange")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    VolumicElectromagneticEnergy = URIRef("http://qudt.org/vocab/quantitykind/VolumicElectromagneticEnergy")
    AngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/AngularFrequency")
    LinearAcceleration = URIRef("http://qudt.org/vocab/quantitykind/LinearAcceleration")
    PhaseCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PhaseCoefficient")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    AbsoluteTypographicMeasurement = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteTypographicMeasurement")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption = URIRef("http://qudt.org/vocab/quantitykind/EinsteinTransitionProbabilityForSpontaneousOrInducedEmissionAndAbsorption")
    AbsorbedDose = URIRef("http://qudt.org/vocab/quantitykind/AbsorbedDose")
    SoundEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SoundEnergyDensity")
    PropellantMeanBulkTemperature = URIRef("http://qudt.org/vocab/quantitykind/PropellantMeanBulkTemperature")
    DataTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/DataTransmissionRate")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    ResistanceRatio = URIRef("http://qudt.org/vocab/quantitykind/ResistanceRatio")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    StandardGravitationalParameter = URIRef("http://qudt.org/vocab/quantitykind/StandardGravitationalParameter")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    TotalCurrent = URIRef("http://qudt.org/vocab/quantitykind/TotalCurrent")
    DewPointTemperature = URIRef("http://qudt.org/vocab/quantitykind/DewPointTemperature")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    SolidStateDiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/SolidStateDiffusionLength")
    LowerCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/LowerCriticalMagneticFluxDensity")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    CENTER_OF_GRAVITY_Y = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Y")
    ExhaustStreamPower = URIRef("http://qudt.org/vocab/quantitykind/ExhaustStreamPower")
    MaximumBeta_ParticleEnergy = URIRef("http://qudt.org/vocab/quantitykind/MaximumBeta-ParticleEnergy")
    IsothermalCompressibility = URIRef("http://qudt.org/vocab/quantitykind/IsothermalCompressibility")
    SourceVoltage = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltage")
    ThermalInsulation = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulation")
    Gain = URIRef("http://qudt.org/vocab/quantitykind/Gain")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    Conductance = URIRef("http://qudt.org/vocab/quantitykind/Conductance")
    MolarConductivity = URIRef("http://qudt.org/vocab/quantitykind/MolarConductivity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    KinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/KinematicViscosity")
    ReactorTimeConstant = URIRef("http://qudt.org/vocab/quantitykind/ReactorTimeConstant")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    SpecificHeatsRatio = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatsRatio")
    Gravity_API = URIRef("http://qudt.org/vocab/quantitykind/Gravity_API")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    AmountOfBiologicallyActiveSubstance = URIRef("http://qudt.org/vocab/quantitykind/AmountOfBiologicallyActiveSubstance")
    LinearVelocity = URIRef("http://qudt.org/vocab/quantitykind/LinearVelocity")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Half_Life = URIRef("http://qudt.org/vocab/quantitykind/Half-Life")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    AtomicAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AtomicAttenuationCoefficient")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    LinearEnergyTransfer = URIRef("http://qudt.org/vocab/quantitykind/LinearEnergyTransfer")
    MolarThermodynamicEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarThermodynamicEnergy")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    QuarticElectricDipoleMomentPerCubicEnergy = URIRef("http://qudt.org/vocab/quantitykind/QuarticElectricDipoleMomentPerCubicEnergy")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    MagneticMoment = URIRef("http://qudt.org/vocab/quantitykind/MagneticMoment")
    StructureFactor = URIRef("http://qudt.org/vocab/quantitykind/StructureFactor")
    SuperconductionTransitionTemperature = URIRef("http://qudt.org/vocab/quantitykind/SuperconductionTransitionTemperature")
    MassFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MassFluxDensity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    SpectralCrossSection = URIRef("http://qudt.org/vocab/quantitykind/SpectralCrossSection")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    Turns = URIRef("http://qudt.org/vocab/quantitykind/Turns")
    SystolicBloodPressure = URIRef("http://qudt.org/vocab/quantitykind/SystolicBloodPressure")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SpecificHeatCapacityAtConstantVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantVolume")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    PayloadMass = URIRef("http://qudt.org/vocab/quantitykind/PayloadMass")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    PRODUCT_OF_INERTIA_Y = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA_Y")
    RadiantIntensity = URIRef("http://qudt.org/vocab/quantitykind/RadiantIntensity")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    CurrencyPerFlight = URIRef("http://qudt.org/vocab/quantitykind/CurrencyPerFlight")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    Asset = URIRef("http://qudt.org/vocab/quantitykind/Asset")
    LiquidVolume = URIRef("http://qudt.org/vocab/quantitykind/LiquidVolume")
    CurieTemperature = URIRef("http://qudt.org/vocab/quantitykind/CurieTemperature")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    MagneticDipoleMomentOfAMolecule = URIRef("http://qudt.org/vocab/quantitykind/MagneticDipoleMomentOfAMolecule")
    MeanLifetime = URIRef("http://qudt.org/vocab/quantitykind/MeanLifetime")
    RadiantExposure = URIRef("http://qudt.org/vocab/quantitykind/RadiantExposure")
    AtomicCharge = URIRef("http://qudt.org/vocab/quantitykind/AtomicCharge")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    CyclotronAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/CyclotronAngularFrequency")
    GrowingDegreeDay_Cereal = URIRef("http://qudt.org/vocab/quantitykind/GrowingDegreeDay_Cereal")
    RESERVE_MASS = URIRef("http://qudt.org/vocab/quantitykind/RESERVE-MASS")
    StateDensityAsExpressionOfAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/StateDensityAsExpressionOfAngularFrequency")
    Admittance = URIRef("http://qudt.org/vocab/quantitykind/Admittance")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    RefractiveIndex = URIRef("http://qudt.org/vocab/quantitykind/RefractiveIndex")
    MolarAbsorptionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/MolarAbsorptionCoefficient")
    CelsiusTemperature = URIRef("http://qudt.org/vocab/quantitykind/CelsiusTemperature")
    EnergyFluence = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluence")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    GrandCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/GrandCanonicalPartitionFunction")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    Absorptance = URIRef("http://qudt.org/vocab/quantitykind/Absorptance")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    InformationContent = URIRef("http://qudt.org/vocab/quantitykind/InformationContent")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    LengthEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthEnergy")
    ReactionEnergy = URIRef("http://qudt.org/vocab/quantitykind/ReactionEnergy")
    Rotary_TranslatoryMotionConversion = URIRef("http://qudt.org/vocab/quantitykind/Rotary-TranslatoryMotionConversion")
    MassExcess = URIRef("http://qudt.org/vocab/quantitykind/MassExcess")
    ShannonDiversityIndex = URIRef("http://qudt.org/vocab/quantitykind/ShannonDiversityIndex")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    LinearAttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LinearAttenuationCoefficient")
    InfiniteMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/InfiniteMultiplicationFactor")
    StaticFriction = URIRef("http://qudt.org/vocab/quantitykind/StaticFriction")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    StagePropellantMass = URIRef("http://qudt.org/vocab/quantitykind/StagePropellantMass")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    RotationalStiffness = URIRef("http://qudt.org/vocab/quantitykind/RotationalStiffness")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    SecondAxialMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/SecondAxialMomentOfArea")
    ThermalAdmittance = URIRef("http://qudt.org/vocab/quantitykind/ThermalAdmittance")
    InstantaneousPower = URIRef("http://qudt.org/vocab/quantitykind/InstantaneousPower")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    DensityOfTheExhaustGases = URIRef("http://qudt.org/vocab/quantitykind/DensityOfTheExhaustGases")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    CartesianArea = URIRef("http://qudt.org/vocab/quantitykind/CartesianArea")
    PoissonRatio = URIRef("http://qudt.org/vocab/quantitykind/PoissonRatio")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    Wavenumber = URIRef("http://qudt.org/vocab/quantitykind/Wavenumber")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    ChargeNumber = URIRef("http://qudt.org/vocab/quantitykind/ChargeNumber")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    SpecificHeatCapacityAtConstantPressure = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacityAtConstantPressure")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    SpecificActivity = URIRef("http://qudt.org/vocab/quantitykind/SpecificActivity")
    AtomicNumber = URIRef("http://qudt.org/vocab/quantitykind/AtomicNumber")
    AtomScatteringFactor = URIRef("http://qudt.org/vocab/quantitykind/AtomScatteringFactor")
    LarmorAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/LarmorAngularFrequency")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    Entropy = URIRef("http://qudt.org/vocab/quantitykind/Entropy")
    NormalizedDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/NormalizedDimensionlessRatio")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    Fluidity = URIRef("http://qudt.org/vocab/quantitykind/Fluidity")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    Emissivity = URIRef("http://qudt.org/vocab/quantitykind/Emissivity")
    PlaneAngle = URIRef("http://qudt.org/vocab/quantitykind/PlaneAngle")
    PositiveLength = URIRef("http://qudt.org/vocab/quantitykind/PositiveLength")
    AmountOfSubstancePerUnitMass = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstancePerUnitMass")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    Loudness = URIRef("http://qudt.org/vocab/quantitykind/Loudness")
    CENTER_OF_GRAVITY_X = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_X")
    LevelWidth = URIRef("http://qudt.org/vocab/quantitykind/LevelWidth")
    TimeRatio = URIRef("http://qudt.org/vocab/quantitykind/TimeRatio")
    ResonanceEscapeProbabilityForFission = URIRef("http://qudt.org/vocab/quantitykind/ResonanceEscapeProbabilityForFission")
    MassDefect = URIRef("http://qudt.org/vocab/quantitykind/MassDefect")
    VerticalVelocity = URIRef("http://qudt.org/vocab/quantitykind/VerticalVelocity")
    MeanEnergyImparted = URIRef("http://qudt.org/vocab/quantitykind/MeanEnergyImparted")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    SpatialSummationFunction = URIRef("http://qudt.org/vocab/quantitykind/SpatialSummationFunction")
    TemperatureRelatedMolarMass = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRelatedMolarMass")
    Unbalance = URIRef("http://qudt.org/vocab/quantitykind/Unbalance")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    BendingMomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/BendingMomentOfForce")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    CombinedNonEvaporativeHeatTransferCoefficient = URIRef("http://qudt.org/vocab/quantitykind/CombinedNonEvaporativeHeatTransferCoefficient")
    AngleOfOpticalRotation = URIRef("http://qudt.org/vocab/quantitykind/AngleOfOpticalRotation")
    Reactance = URIRef("http://qudt.org/vocab/quantitykind/Reactance")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    Depth = URIRef("http://qudt.org/vocab/quantitykind/Depth")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    DisplacementCurrent = URIRef("http://qudt.org/vocab/quantitykind/DisplacementCurrent")
    SpectralLuminousEfficiency = URIRef("http://qudt.org/vocab/quantitykind/SpectralLuminousEfficiency")
    ParticlePositionVector = URIRef("http://qudt.org/vocab/quantitykind/ParticlePositionVector")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    Irradiance = URIRef("http://qudt.org/vocab/quantitykind/Irradiance")
    EnergyDensityOfStates = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensityOfStates")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    Lethargy = URIRef("http://qudt.org/vocab/quantitykind/Lethargy")
    VehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/VehicleVelocity")
    MassNumber = URIRef("http://qudt.org/vocab/quantitykind/MassNumber")
    ThermalResistance = URIRef("http://qudt.org/vocab/quantitykind/ThermalResistance")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    VolumeStrain = URIRef("http://qudt.org/vocab/quantitykind/VolumeStrain")
    TorqueConstant = URIRef("http://qudt.org/vocab/quantitykind/TorqueConstant")
    SurfaceTension = URIRef("http://qudt.org/vocab/quantitykind/SurfaceTension")
    ElectricSusceptibility = URIRef("http://qudt.org/vocab/quantitykind/ElectricSusceptibility")
    SoundReductionIndex = URIRef("http://qudt.org/vocab/quantitykind/SoundReductionIndex")
    FlashPoint = URIRef("http://qudt.org/vocab/quantitykind/FlashPoint")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    BloodGlucoseLevel_Mass = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel_Mass")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    Permittivity = URIRef("http://qudt.org/vocab/quantitykind/Permittivity")
    AtomicMass = URIRef("http://qudt.org/vocab/quantitykind/AtomicMass")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    SpectralRadiantEnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/SpectralRadiantEnergyDensity")
    MacroscopicTotalCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicTotalCrossSection")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    LinkedFlux = URIRef("http://qudt.org/vocab/quantitykind/LinkedFlux")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    TemperatureBasedKinematicViscosity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedKinematicViscosity")
    SpecificHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatCapacity")
    LinearThermalExpansion = URIRef("http://qudt.org/vocab/quantitykind/LinearThermalExpansion")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MomentOfForce = URIRef("http://qudt.org/vocab/quantitykind/MomentOfForce")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    RotationalMass = URIRef("http://qudt.org/vocab/quantitykind/RotationalMass")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    ElectricChargeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeDensity")
    SoundParticleDisplacement = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleDisplacement")
    FissionFuelUtilizationFactor = URIRef("http://qudt.org/vocab/quantitykind/FissionFuelUtilizationFactor")
    Speed = URIRef("http://qudt.org/vocab/quantitykind/Speed")
    ThermalInsulance = URIRef("http://qudt.org/vocab/quantitykind/ThermalInsulance")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    HeatFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/HeatFluxDensity")
    BraggAngle = URIRef("http://qudt.org/vocab/quantitykind/BraggAngle")
    Acceleration = URIRef("http://qudt.org/vocab/quantitykind/Acceleration")
    LuminousEmittance = URIRef("http://qudt.org/vocab/quantitykind/LuminousEmittance")
    BatteryCapacity = URIRef("http://qudt.org/vocab/quantitykind/BatteryCapacity")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    MassFractionOfDryMatter = URIRef("http://qudt.org/vocab/quantitykind/MassFractionOfDryMatter")
    SymbolTransmissionRate = URIRef("http://qudt.org/vocab/quantitykind/SymbolTransmissionRate")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    MicroCanonicalPartitionFunction = URIRef("http://qudt.org/vocab/quantitykind/MicroCanonicalPartitionFunction")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CatalyticActivity = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivity")
    GapEnergy = URIRef("http://qudt.org/vocab/quantitykind/GapEnergy")
    SoundPower = URIRef("http://qudt.org/vocab/quantitykind/SoundPower")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    GROSS_LIFT_OFF_WEIGHT = URIRef("http://qudt.org/vocab/quantitykind/GROSS-LIFT-OFF-WEIGHT")
    PackingFraction = URIRef("http://qudt.org/vocab/quantitykind/PackingFraction")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MolarVolume = URIRef("http://qudt.org/vocab/quantitykind/MolarVolume")
    OrbitalRadialDistance = URIRef("http://qudt.org/vocab/quantitykind/OrbitalRadialDistance")
    MacroscopicCrossSection = URIRef("http://qudt.org/vocab/quantitykind/MacroscopicCrossSection")
    EnergyPerMagneticFluxDensity_Squared = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerMagneticFluxDensity_Squared")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    SpecificEntropy = URIRef("http://qudt.org/vocab/quantitykind/SpecificEntropy")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    BitDataVolume = URIRef("http://qudt.org/vocab/quantitykind/BitDataVolume")
    LandeGFactor = URIRef("http://qudt.org/vocab/quantitykind/LandeGFactor")
    ElectricCurrent = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrent")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    PowerPerAreaAngle = URIRef("http://qudt.org/vocab/quantitykind/PowerPerAreaAngle")
    ElectricQuadrupoleMoment = URIRef("http://qudt.org/vocab/quantitykind/ElectricQuadrupoleMoment")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    NozzleWallsThrustReaction = URIRef("http://qudt.org/vocab/quantitykind/NozzleWallsThrustReaction")
    ThermalEnergyLength = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergyLength")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    Duv = URIRef("http://qudt.org/vocab/quantitykind/Duv")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    Ratio = URIRef("http://qudt.org/vocab/quantitykind/Ratio")
    ThermalExpansionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalExpansionCoefficient")
    InverseTimeTemperature = URIRef("http://qudt.org/vocab/quantitykind/InverseTimeTemperature")
    MassAmountOfSubstanceTemperature = URIRef("http://qudt.org/vocab/quantitykind/MassAmountOfSubstanceTemperature")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    Velocity = URIRef("http://qudt.org/vocab/quantitykind/Velocity")
    PositiveDimensionlessRatio = URIRef("http://qudt.org/vocab/quantitykind/PositiveDimensionlessRatio")
    RadiativeHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/RadiativeHeatTransfer")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    ConductionSpeed = URIRef("http://qudt.org/vocab/quantitykind/ConductionSpeed")
    SpectralConcentrationOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralConcentrationOfVibrationalModes")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LinearMomentum = URIRef("http://qudt.org/vocab/quantitykind/LinearMomentum")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    PowerPerElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/PowerPerElectricCharge")
    MolecularViscosity = URIRef("http://qudt.org/vocab/quantitykind/MolecularViscosity")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MassicHeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/MassicHeatCapacity")
    GravitationalAttraction = URIRef("http://qudt.org/vocab/quantitykind/GravitationalAttraction")
    SpecificImpulseByMass = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulseByMass")
    CrossSection = URIRef("http://qudt.org/vocab/quantitykind/CrossSection")
    SpecificImpulse = URIRef("http://qudt.org/vocab/quantitykind/SpecificImpulse")
    VoltagePercentage = URIRef("http://qudt.org/vocab/quantitykind/VoltagePercentage")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    Area = URIRef("http://qudt.org/vocab/quantitykind/Area")
    RatioOfSpecificHeatCapacities = URIRef("http://qudt.org/vocab/quantitykind/RatioOfSpecificHeatCapacities")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    Half_ValueThickness = URIRef("http://qudt.org/vocab/quantitykind/Half-ValueThickness")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    DiffusionArea = URIRef("http://qudt.org/vocab/quantitykind/DiffusionArea")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    TotalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/TotalAngularMomentumQuantumNumber")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    NuclearRadius = URIRef("http://qudt.org/vocab/quantitykind/NuclearRadius")
    Enthalpy = URIRef("http://qudt.org/vocab/quantitykind/Enthalpy")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    AngleOfAttack = URIRef("http://qudt.org/vocab/quantitykind/AngleOfAttack")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    CarrierLifetime = URIRef("http://qudt.org/vocab/quantitykind/CarrierLifetime")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    ModulusOfElasticity = URIRef("http://qudt.org/vocab/quantitykind/ModulusOfElasticity")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    ElectricCurrentPhasor = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentPhasor")
    DiffusionCoefficient = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficient")
    PressureBasedMass = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    SeebeckCoefficient = URIRef("http://qudt.org/vocab/quantitykind/SeebeckCoefficient")
    VisibleRadiantEnergy = URIRef("http://qudt.org/vocab/quantitykind/VisibleRadiantEnergy")
    KineticEnergy = URIRef("http://qudt.org/vocab/quantitykind/KineticEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    AreaPerPower = URIRef("http://qudt.org/vocab/quantitykind/AreaPerPower")
    Temperature = URIRef("http://qudt.org/vocab/quantitykind/Temperature")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    CartesianVolume = URIRef("http://qudt.org/vocab/quantitykind/CartesianVolume")
    MassPerArea = URIRef("http://qudt.org/vocab/quantitykind/MassPerArea")
    FundamentalLatticeVector = URIRef("http://qudt.org/vocab/quantitykind/FundamentalLatticeVector")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ChemicalAffinity = URIRef("http://qudt.org/vocab/quantitykind/ChemicalAffinity")
    FermiEnergy = URIRef("http://qudt.org/vocab/quantitykind/FermiEnergy")
    MagneticQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/MagneticQuantumNumber")
    IonTransportNumber = URIRef("http://qudt.org/vocab/quantitykind/IonTransportNumber")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    CONTROL_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTROL-MASS")
    Work = URIRef("http://qudt.org/vocab/quantitykind/Work")
    LinearStiffness = URIRef("http://qudt.org/vocab/quantitykind/LinearStiffness")
    AmountOfSubstanceFractionOfB = URIRef("http://qudt.org/vocab/quantitykind/AmountOfSubstanceFractionOfB")
    CostPerUnitEnergy = URIRef("http://qudt.org/vocab/quantitykind/CostPerUnitEnergy")
    ElectromagneticPermeability = URIRef("http://qudt.org/vocab/quantitykind/ElectromagneticPermeability")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    NeutronNumber = URIRef("http://qudt.org/vocab/quantitykind/NeutronNumber")
    SolidAngle = URIRef("http://qudt.org/vocab/quantitykind/SolidAngle")
    RelativeMassConcentrationOfVapour = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassConcentrationOfVapour")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    PH = URIRef("http://qudt.org/vocab/quantitykind/PH")
    LogarithmRatioToBaseE = URIRef("http://qudt.org/vocab/quantitykind/LogarithmRatioToBaseE")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    MASS_GROWTH_ALLOWANCE = URIRef("http://qudt.org/vocab/quantitykind/MASS-GROWTH-ALLOWANCE")
    InverseLength = URIRef("http://qudt.org/vocab/quantitykind/InverseLength")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ElectronRadius = URIRef("http://qudt.org/vocab/quantitykind/ElectronRadius")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    Force = URIRef("http://qudt.org/vocab/quantitykind/Force")
    EnergyFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/EnergyFluenceRate")
    StaticPressure = URIRef("http://qudt.org/vocab/quantitykind/StaticPressure")
    CompressibilityFactor = URIRef("http://qudt.org/vocab/quantitykind/CompressibilityFactor")
    PictureElement = URIRef("http://qudt.org/vocab/quantitykind/PictureElement")
    ElectricChargeVolumeDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricChargeVolumeDensity")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    EnergyDensity = URIRef("http://qudt.org/vocab/quantitykind/EnergyDensity")
    EnergyPerArea = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerArea")
    ElectronMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/ElectronMeanFreePath")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    BiodegredationHalfLife = URIRef("http://qudt.org/vocab/quantitykind/BiodegredationHalfLife")
    RadiantEmmitance = URIRef("http://qudt.org/vocab/quantitykind/RadiantEmmitance")
    SpectralDensityOfVibrationalModes = URIRef("http://qudt.org/vocab/quantitykind/SpectralDensityOfVibrationalModes")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    SpecificHeatVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificHeatVolume")
    HorizontalVelocity = URIRef("http://qudt.org/vocab/quantitykind/HorizontalVelocity")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    DoseEquivalent = URIRef("http://qudt.org/vocab/quantitykind/DoseEquivalent")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ThermalUtilizationFactorForFission = URIRef("http://qudt.org/vocab/quantitykind/ThermalUtilizationFactorForFission")
    WorkFunction = URIRef("http://qudt.org/vocab/quantitykind/WorkFunction")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    MassFlowRate = URIRef("http://qudt.org/vocab/quantitykind/MassFlowRate")
    PRODUCT_OF_INERTIA = URIRef("http://qudt.org/vocab/quantitykind/PRODUCT-OF-INERTIA")
    EffectiveMass = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMass")
    RadiusOfCurvature = URIRef("http://qudt.org/vocab/quantitykind/RadiusOfCurvature")
    CurrentLinkage = URIRef("http://qudt.org/vocab/quantitykind/CurrentLinkage")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    AlphaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AlphaDisintegrationEnergy")
    Power = URIRef("http://qudt.org/vocab/quantitykind/Power")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    ElectronDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectronDensity")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    HenrysLawVolatilityConstant = URIRef("http://qudt.org/vocab/quantitykind/HenrysLawVolatilityConstant")
    MassOfElectricalPowerSupply = URIRef("http://qudt.org/vocab/quantitykind/MassOfElectricalPowerSupply")
    PropellantMass = URIRef("http://qudt.org/vocab/quantitykind/PropellantMass")
    ThomsonCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThomsonCoefficient")
    Torque = URIRef("http://qudt.org/vocab/quantitykind/Torque")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    Friction = URIRef("http://qudt.org/vocab/quantitykind/Friction")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    EarthClosestApproachVehicleVelocity = URIRef("http://qudt.org/vocab/quantitykind/EarthClosestApproachVehicleVelocity")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    AtmosphericHydroxylationRate = URIRef("http://qudt.org/vocab/quantitykind/AtmosphericHydroxylationRate")
    CenterOfGravity_X = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_X")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    EquilibriumPositionVectorOfIon = URIRef("http://qudt.org/vocab/quantitykind/EquilibriumPositionVectorOfIon")
    MassOfSolidBooster = URIRef("http://qudt.org/vocab/quantitykind/MassOfSolidBooster")
    Heat = URIRef("http://qudt.org/vocab/quantitykind/Heat")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    LineicQuantity = URIRef("http://qudt.org/vocab/quantitykind/LineicQuantity")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    NonActivePower = URIRef("http://qudt.org/vocab/quantitykind/NonActivePower")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    CatalyticActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/CatalyticActivityConcentration")
    TARGET_BOGIE_MASS = URIRef("http://qudt.org/vocab/quantitykind/TARGET-BOGIE-MASS")
    MoistureDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/MoistureDiffusivity")
    FUEL_BIAS = URIRef("http://qudt.org/vocab/quantitykind/FUEL-BIAS")
    MeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/MeanFreePath")
    SuperconductorEnergyGap = URIRef("http://qudt.org/vocab/quantitykind/SuperconductorEnergyGap")
    MolecularConcentration = URIRef("http://qudt.org/vocab/quantitykind/MolecularConcentration")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    IonCurrent = URIRef("http://qudt.org/vocab/quantitykind/IonCurrent")
    RadiantFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/RadiantFluenceRate")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    VolumeOrSectionModulus = URIRef("http://qudt.org/vocab/quantitykind/VolumeOrSectionModulus")
    ActivityRelatedByMass = URIRef("http://qudt.org/vocab/quantitykind/ActivityRelatedByMass")
    EnergyPerAreaElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/EnergyPerAreaElectricCharge")
    MachNumber = URIRef("http://qudt.org/vocab/quantitykind/MachNumber")
    ActivityConcentration = URIRef("http://qudt.org/vocab/quantitykind/ActivityConcentration")
    Resistance = URIRef("http://qudt.org/vocab/quantitykind/Resistance")
    StateDensity = URIRef("http://qudt.org/vocab/quantitykind/StateDensity")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    LuminousEfficacy = URIRef("http://qudt.org/vocab/quantitykind/LuminousEfficacy")
    PathLength = URIRef("http://qudt.org/vocab/quantitykind/PathLength")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    TemperatureBasedQuantity = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedQuantity")
    OverRangeDistance = URIRef("http://qudt.org/vocab/quantitykind/OverRangeDistance")
    MigrationLength = URIRef("http://qudt.org/vocab/quantitykind/MigrationLength")
    MolarOpticalRotatoryPower = URIRef("http://qudt.org/vocab/quantitykind/MolarOpticalRotatoryPower")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Strain = URIRef("http://qudt.org/vocab/quantitykind/Strain")
    MassieuFunction = URIRef("http://qudt.org/vocab/quantitykind/MassieuFunction")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    FLIGHT_PERFORMANCE_RESERVE_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/FLIGHT-PERFORMANCE-RESERVE-PROPELLANT-MASS")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    AtomicStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/AtomicStoppingPower")
    ThermalCapacitance = URIRef("http://qudt.org/vocab/quantitykind/ThermalCapacitance")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ElectricPolarizability = URIRef("http://qudt.org/vocab/quantitykind/ElectricPolarizability")
    ElectricPropulsionPropellantMass = URIRef("http://qudt.org/vocab/quantitykind/ElectricPropulsionPropellantMass")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    VacuumThrust = URIRef("http://qudt.org/vocab/quantitykind/VacuumThrust")
    SignalStrength = URIRef("http://qudt.org/vocab/quantitykind/SignalStrength")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    LuminousFlux = URIRef("http://qudt.org/vocab/quantitykind/LuminousFlux")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    DiffusionLength = URIRef("http://qudt.org/vocab/quantitykind/DiffusionLength")
    VolumeFlowRate = URIRef("http://qudt.org/vocab/quantitykind/VolumeFlowRate")
    BetaDisintegrationEnergy = URIRef("http://qudt.org/vocab/quantitykind/BetaDisintegrationEnergy")
    EnergyInternal = URIRef("http://qudt.org/vocab/quantitykind/EnergyInternal")
    LuminousExposure = URIRef("http://qudt.org/vocab/quantitykind/LuminousExposure")
    ReverberationTime = URIRef("http://qudt.org/vocab/quantitykind/ReverberationTime")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    SoundParticleVelocity = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleVelocity")
    Density = URIRef("http://qudt.org/vocab/quantitykind/Density")
    ActivityThresholds = URIRef("http://qudt.org/vocab/quantitykind/ActivityThresholds")
    AngularImpulse = URIRef("http://qudt.org/vocab/quantitykind/AngularImpulse")
    ElectronAffinity = URIRef("http://qudt.org/vocab/quantitykind/ElectronAffinity")
    MomentOfInertia = URIRef("http://qudt.org/vocab/quantitykind/MomentOfInertia")
    Impedance = URIRef("http://qudt.org/vocab/quantitykind/Impedance")
    HoleDensity = URIRef("http://qudt.org/vocab/quantitykind/HoleDensity")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    LuminousFluxRatio = URIRef("http://qudt.org/vocab/quantitykind/LuminousFluxRatio")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    LiftCoefficient = URIRef("http://qudt.org/vocab/quantitykind/LiftCoefficient")
    BucklingFactor = URIRef("http://qudt.org/vocab/quantitykind/BucklingFactor")
    SurfaceCoefficientOfHeatTransfer = URIRef("http://qudt.org/vocab/quantitykind/SurfaceCoefficientOfHeatTransfer")
    AttenuationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/AttenuationCoefficient")
    LogarithmicFrequencyIntervalToBase10 = URIRef("http://qudt.org/vocab/quantitykind/LogarithmicFrequencyIntervalToBase10")
    ShearStress = URIRef("http://qudt.org/vocab/quantitykind/ShearStress")
    MolarInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MolarInternalEnergy")
    Viscosity = URIRef("http://qudt.org/vocab/quantitykind/Viscosity")
    ElectricFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricFluxDensity")
    FinalOrCurrentVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/FinalOrCurrentVehicleMass")
    NucleonNumber = URIRef("http://qudt.org/vocab/quantitykind/NucleonNumber")
    PhononMeanFreePath = URIRef("http://qudt.org/vocab/quantitykind/PhononMeanFreePath")
    AngularAcceleration = URIRef("http://qudt.org/vocab/quantitykind/AngularAcceleration")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    RelativeMassDefect = URIRef("http://qudt.org/vocab/quantitykind/RelativeMassDefect")
    Stress = URIRef("http://qudt.org/vocab/quantitykind/Stress")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    DRY_MASS = URIRef("http://qudt.org/vocab/quantitykind/DRY-MASS")
    BevelGearPitchAngle = URIRef("http://qudt.org/vocab/quantitykind/BevelGearPitchAngle")
    PermittivityRatio = URIRef("http://qudt.org/vocab/quantitykind/PermittivityRatio")
    Radius = URIRef("http://qudt.org/vocab/quantitykind/Radius")
    MaxOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxOperatingThrust")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    HeatingValue = URIRef("http://qudt.org/vocab/quantitykind/HeatingValue")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    EquivalentAbsorptionArea = URIRef("http://qudt.org/vocab/quantitykind/EquivalentAbsorptionArea")
    ApparentPower = URIRef("http://qudt.org/vocab/quantitykind/ApparentPower")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    LondonPenetrationDepth = URIRef("http://qudt.org/vocab/quantitykind/LondonPenetrationDepth")
    ElectricConductivity = URIRef("http://qudt.org/vocab/quantitykind/ElectricConductivity")
    WarpingMoment = URIRef("http://qudt.org/vocab/quantitykind/WarpingMoment")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Thickness = URIRef("http://qudt.org/vocab/quantitykind/Thickness")
    ThermalDiffusionRatioCoefficient = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionRatioCoefficient")
    HamiltonFunction = URIRef("http://qudt.org/vocab/quantitykind/HamiltonFunction")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    BodyMassIndex = URIRef("http://qudt.org/vocab/quantitykind/BodyMassIndex")
    Fugacity = URIRef("http://qudt.org/vocab/quantitykind/Fugacity")
    RadiantFlux = URIRef("http://qudt.org/vocab/quantitykind/RadiantFlux")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    DebyeAngularFrequency = URIRef("http://qudt.org/vocab/quantitykind/DebyeAngularFrequency")
    Mass = URIRef("http://qudt.org/vocab/quantitykind/Mass")
    ReactivePower = URIRef("http://qudt.org/vocab/quantitykind/ReactivePower")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    ResidualResistivity = URIRef("http://qudt.org/vocab/quantitykind/ResidualResistivity")
    AngularWavenumber = URIRef("http://qudt.org/vocab/quantitykind/AngularWavenumber")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    EnergyLevel = URIRef("http://qudt.org/vocab/quantitykind/EnergyLevel")
    EffectiveMultiplicationFactor = URIRef("http://qudt.org/vocab/quantitykind/EffectiveMultiplicationFactor")
    SpecificVolume = URIRef("http://qudt.org/vocab/quantitykind/SpecificVolume")
    Chromaticity = URIRef("http://qudt.org/vocab/quantitykind/Chromaticity")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    Distance = URIRef("http://qudt.org/vocab/quantitykind/Distance")
    MassDensity = URIRef("http://qudt.org/vocab/quantitykind/MassDensity")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    FissionCoreRadiusToHeightRatio = URIRef("http://qudt.org/vocab/quantitykind/FissionCoreRadiusToHeightRatio")
    PotentialEnergy = URIRef("http://qudt.org/vocab/quantitykind/PotentialEnergy")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    MassPerLength = URIRef("http://qudt.org/vocab/quantitykind/MassPerLength")
    ColdReceptorThreshold = URIRef("http://qudt.org/vocab/quantitykind/ColdReceptorThreshold")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    PressureBasedDynamicViscosity = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedDynamicViscosity")
    VolumetricFlux = URIRef("http://qudt.org/vocab/quantitykind/VolumetricFlux")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    PressureRatio = URIRef("http://qudt.org/vocab/quantitykind/PressureRatio")
    PressureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedAmountOfSubstanceConcentration")
    IonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/IonizationEnergy")
    MadelungConstant = URIRef("http://qudt.org/vocab/quantitykind/MadelungConstant")
    MassPerEnergy = URIRef("http://qudt.org/vocab/quantitykind/MassPerEnergy")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    SpecificThrust = URIRef("http://qudt.org/vocab/quantitykind/SpecificThrust")
    BloodGlucoseLevel = URIRef("http://qudt.org/vocab/quantitykind/BloodGlucoseLevel")
    EllipticalOrbitApogeeVelocity = URIRef("http://qudt.org/vocab/quantitykind/EllipticalOrbitApogeeVelocity")
    GasLeakRate = URIRef("http://qudt.org/vocab/quantitykind/GasLeakRate")
    IonicCharge = URIRef("http://qudt.org/vocab/quantitykind/IonicCharge")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    VaporPressure = URIRef("http://qudt.org/vocab/quantitykind/VaporPressure")
    InverseVolume = URIRef("http://qudt.org/vocab/quantitykind/InverseVolume")
    MagneticFlux = URIRef("http://qudt.org/vocab/quantitykind/MagneticFlux")
    GibbsEnergy = URIRef("http://qudt.org/vocab/quantitykind/GibbsEnergy")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    SpecificHelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificHelmholtzEnergy")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    WaterHorsepower = URIRef("http://qudt.org/vocab/quantitykind/WaterHorsepower")
    CouplingFactor = URIRef("http://qudt.org/vocab/quantitykind/CouplingFactor")
    SectionModulus = URIRef("http://qudt.org/vocab/quantitykind/SectionModulus")
    NOMINAL_ASCENT_PROPELLANT_MASS = URIRef("http://qudt.org/vocab/quantitykind/NOMINAL-ASCENT-PROPELLANT-MASS")
    Energy = URIRef("http://qudt.org/vocab/quantitykind/Energy")
    ElectricDisplacementField = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacementField")
    Slowing_DownArea = URIRef("http://qudt.org/vocab/quantitykind/Slowing-DownArea")
    Dissipance = URIRef("http://qudt.org/vocab/quantitykind/Dissipance")
    AngularDistance = URIRef("http://qudt.org/vocab/quantitykind/AngularDistance")
    IncidenceRate = URIRef("http://qudt.org/vocab/quantitykind/IncidenceRate")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")
    ThermalEnergy = URIRef("http://qudt.org/vocab/quantitykind/ThermalEnergy")
    Volume = URIRef("http://qudt.org/vocab/quantitykind/Volume")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    ThermalEfficiency = URIRef("http://qudt.org/vocab/quantitykind/ThermalEfficiency")
    ThermalDiffusionFactor = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusionFactor")
    ComplexFrequency_Real = URIRef("http://qudt.org/vocab/quantitykind/ComplexFrequency_Real")
    MaxExpectedOperatingThrust = URIRef("http://qudt.org/vocab/quantitykind/MaxExpectedOperatingThrust")
    Breadth = URIRef("http://qudt.org/vocab/quantitykind/Breadth")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    GeneralizedMomentum = URIRef("http://qudt.org/vocab/quantitykind/GeneralizedMomentum")
    Altitude = URIRef("http://qudt.org/vocab/quantitykind/Altitude")
    PropagationCoefficient = URIRef("http://qudt.org/vocab/quantitykind/PropagationCoefficient")
    Height = URIRef("http://qudt.org/vocab/quantitykind/Height")
    MASS_DELIVERED = URIRef("http://qudt.org/vocab/quantitykind/MASS-DELIVERED")
    CENTER_OF_GRAVITY_Z = URIRef("http://qudt.org/vocab/quantitykind/CENTER-OF-GRAVITY_Z")
    Inductance = URIRef("http://qudt.org/vocab/quantitykind/Inductance")
    MagneticFieldStrength_H = URIRef("http://qudt.org/vocab/quantitykind/MagneticFieldStrength_H")
    OrbitalAngularMomentumQuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/OrbitalAngularMomentumQuantumNumber")
    MagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/MagneticFluxDensity")
    PressureBasedLength = URIRef("http://qudt.org/vocab/quantitykind/PressureBasedLength")
    ElectricCurrentDensity = URIRef("http://qudt.org/vocab/quantitykind/ElectricCurrentDensity")
    ElectricPotentialDifference = URIRef("http://qudt.org/vocab/quantitykind/ElectricPotentialDifference")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    HeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/HeatFlowRate")
    ExposureRate = URIRef("http://qudt.org/vocab/quantitykind/ExposureRate")
    ParticleFluence = URIRef("http://qudt.org/vocab/quantitykind/ParticleFluence")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    TemperatureBasedAmountOfSubstanceConcentration = URIRef("http://qudt.org/vocab/quantitykind/TemperatureBasedAmountOfSubstanceConcentration")
    RelativeHumidity = URIRef("http://qudt.org/vocab/quantitykind/RelativeHumidity")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    QuantumNumber = URIRef("http://qudt.org/vocab/quantitykind/QuantumNumber")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    RestMass = URIRef("http://qudt.org/vocab/quantitykind/RestMass")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Landau_GinzburgNumber = URIRef("http://qudt.org/vocab/quantitykind/Landau-GinzburgNumber")
    ApogeeRadius = URIRef("http://qudt.org/vocab/quantitykind/ApogeeRadius")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    InternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/InternalEnergy")
    ElectricCharge = URIRef("http://qudt.org/vocab/quantitykind/ElectricCharge")
    PositionVector = URIRef("http://qudt.org/vocab/quantitykind/PositionVector")
    InitialNozzleThroatDiameter = URIRef("http://qudt.org/vocab/quantitykind/InitialNozzleThroatDiameter")
    MassPerAreaTime = URIRef("http://qudt.org/vocab/quantitykind/MassPerAreaTime")
    LinearCompressibility = URIRef("http://qudt.org/vocab/quantitykind/LinearCompressibility")
    TotalLinearStoppingPower = URIRef("http://qudt.org/vocab/quantitykind/TotalLinearStoppingPower")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    FirstMomentOfArea = URIRef("http://qudt.org/vocab/quantitykind/FirstMomentOfArea")
    ForcePerArea = URIRef("http://qudt.org/vocab/quantitykind/ForcePerArea")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    NormalStress = URIRef("http://qudt.org/vocab/quantitykind/NormalStress")
    RestEnergy = URIRef("http://qudt.org/vocab/quantitykind/RestEnergy")
    AreicHeatFlowRate = URIRef("http://qudt.org/vocab/quantitykind/AreicHeatFlowRate")
    ElectricPower = URIRef("http://qudt.org/vocab/quantitykind/ElectricPower")
    TimeAveragedSoundIntensity = URIRef("http://qudt.org/vocab/quantitykind/TimeAveragedSoundIntensity")
    Diameter = URIRef("http://qudt.org/vocab/quantitykind/Diameter")
    InitialVehicleMass = URIRef("http://qudt.org/vocab/quantitykind/InitialVehicleMass")
    SourceVoltageBetweenSubstances = URIRef("http://qudt.org/vocab/quantitykind/SourceVoltageBetweenSubstances")
    StageStructuralMass = URIRef("http://qudt.org/vocab/quantitykind/StageStructuralMass")
    InformationEntropy = URIRef("http://qudt.org/vocab/quantitykind/InformationEntropy")
    SpecificInternalEnergy = URIRef("http://qudt.org/vocab/quantitykind/SpecificInternalEnergy")
    MASS_MARGIN = URIRef("http://qudt.org/vocab/quantitykind/MASS-MARGIN")
    DataRate = URIRef("http://qudt.org/vocab/quantitykind/DataRate")
    ClosestApproachRadius = URIRef("http://qudt.org/vocab/quantitykind/ClosestApproachRadius")
    PlanarForce = URIRef("http://qudt.org/vocab/quantitykind/PlanarForce")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Transmittance = URIRef("http://qudt.org/vocab/quantitykind/Transmittance")
    RelativeMolecularMass = URIRef("http://qudt.org/vocab/quantitykind/RelativeMolecularMass")
    Time = URIRef("http://qudt.org/vocab/quantitykind/Time")
    DiffusionCoefficientForFluenceRate = URIRef("http://qudt.org/vocab/quantitykind/DiffusionCoefficientForFluenceRate")
    ThermodynamicCriticalMagneticFluxDensity = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicCriticalMagneticFluxDensity")
    TrueExhaustVelocity = URIRef("http://qudt.org/vocab/quantitykind/TrueExhaustVelocity")
    ElectricDisplacement = URIRef("http://qudt.org/vocab/quantitykind/ElectricDisplacement")
    AccelerationOfGravity = URIRef("http://qudt.org/vocab/quantitykind/AccelerationOfGravity")
    AbsoluteHumidity = URIRef("http://qudt.org/vocab/quantitykind/AbsoluteHumidity")
    DonorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/DonorIonizationEnergy")
    ChemicalPotential = URIRef("http://qudt.org/vocab/quantitykind/ChemicalPotential")
    BurnTime = URIRef("http://qudt.org/vocab/quantitykind/BurnTime")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    AcceptorIonizationEnergy = URIRef("http://qudt.org/vocab/quantitykind/AcceptorIonizationEnergy")
    AuditoryThresholds = URIRef("http://qudt.org/vocab/quantitykind/AuditoryThresholds")
    SoundParticleAcceleration = URIRef("http://qudt.org/vocab/quantitykind/SoundParticleAcceleration")
    ThermodynamicTemperature = URIRef("http://qudt.org/vocab/quantitykind/ThermodynamicTemperature")
    VolumePerArea = URIRef("http://qudt.org/vocab/quantitykind/VolumePerArea")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    AverageEnergyLossPerElementaryChargeProduced = URIRef("http://qudt.org/vocab/quantitykind/AverageEnergyLossPerElementaryChargeProduced")
    Frequency = URIRef("http://qudt.org/vocab/quantitykind/Frequency")
    CenterOfGravity_Y = URIRef("http://qudt.org/vocab/quantitykind/CenterOfGravity_Y")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    MeanMassRange = URIRef("http://qudt.org/vocab/quantitykind/MeanMassRange")
    PropellantBurnRate = URIRef("http://qudt.org/vocab/quantitykind/PropellantBurnRate")
    ThermalDiffusivity = URIRef("http://qudt.org/vocab/quantitykind/ThermalDiffusivity")
    MechanicalEnergy = URIRef("http://qudt.org/vocab/quantitykind/MechanicalEnergy")
    CoherenceLength = URIRef("http://qudt.org/vocab/quantitykind/CoherenceLength")
    WebTime = URIRef("http://qudt.org/vocab/quantitykind/WebTime")
    HeatCapacity = URIRef("http://qudt.org/vocab/quantitykind/HeatCapacity")
    Illuminance = URIRef("http://qudt.org/vocab/quantitykind/Illuminance")
    Exposure = URIRef("http://qudt.org/vocab/quantitykind/Exposure")
    LineicResolution = URIRef("http://qudt.org/vocab/quantitykind/LineicResolution")
    Width = URIRef("http://qudt.org/vocab/quantitykind/Width")
    PhaseDifference = URIRef("http://qudt.org/vocab/quantitykind/PhaseDifference")
    HelmholtzEnergy = URIRef("http://qudt.org/vocab/quantitykind/HelmholtzEnergy")
    LogERatio = URIRef("http://qudt.org/vocab/quantitykind/LogERatio")
    VolumeFraction = URIRef("http://qudt.org/vocab/quantitykind/VolumeFraction")
    Unknown = URIRef("http://qudt.org/vocab/quantitykind/Unknown")
    Wavelength = URIRef("http://qudt.org/vocab/quantitykind/Wavelength")
    ShearModulus = URIRef("http://qudt.org/vocab/quantitykind/ShearModulus")
    SpeedOfSound = URIRef("http://qudt.org/vocab/quantitykind/SpeedOfSound")
    TemperatureRatio = URIRef("http://qudt.org/vocab/quantitykind/TemperatureRatio")
    NonNegativeLength = URIRef("http://qudt.org/vocab/quantitykind/NonNegativeLength")
    CONTRACT_END_ITEM_SPECIFICATION_MASS = URIRef("http://qudt.org/vocab/quantitykind/CONTRACT-END-ITEM-SPECIFICATION-MASS")
    ConductiveHeatTransferRate = URIRef("http://qudt.org/vocab/quantitykind/ConductiveHeatTransferRate")
    LengthMolarEnergy = URIRef("http://qudt.org/vocab/quantitykind/LengthMolarEnergy")
    AngularVelocity = URIRef("http://qudt.org/vocab/quantitykind/AngularVelocity")
    Displacement = URIRef("http://qudt.org/vocab/quantitykind/Displacement")
    ForceMagnitude = URIRef("http://qudt.org/vocab/quantitykind/ForceMagnitude")
    CartesianCoordinates = URIRef("http://qudt.org/vocab/quantitykind/CartesianCoordinates")
    FirstStageMassRatio = URIRef("http://qudt.org/vocab/quantitykind/FirstStageMassRatio")
    MolarMass = URIRef("http://qudt.org/vocab/quantitykind/MolarMass")

    _NS = Namespace("https://qudt.org/vocab/unit/")